@@ -24,6 +24,7 @@
 #include <QObject>
 #include <QVariantMap>
 #include <QStringList>
+#include <QTextCursor>
 
 #include <QDebug>
 
@@ -63,8 +64,14 @@ public:
     QString getSharedById();
     QString getSharedByAvatar();
 
+
+    QString generateTooltip();
+    QString generateSnippet(int charLimit);
+
+
 signals:
 
+
 public slots:
 
 
