@@ -157,6 +157,10 @@ ASObject::ASObject(QVariantMap objectMap,
     content = objectMap.value("content").toString();
 
     likesCount = objectMap.value("likes").toMap().value("totalItems").toString();
+    if (likesCount.isEmpty())
+    {
+        likesCount = "0";
+    }
     commentsCount = objectMap.value("replies").toMap().value("totalItems").toString();
     sharesCount = objectMap.value("shares").toMap().value("totalItems").toString();
 
@@ -328,6 +332,18 @@ QString ASObject::getDeletedTime()
     return this->deleted;
 }
 
+QString ASObject::getDeletedOnString()
+{
+    QString deletedOnString;
+    if (!this->deleted.isEmpty())
+    {
+        deletedOnString = tr("Deleted on %1")
+                          .arg(Timestamp::localTimeDate(this->deleted));
+    }
+
+    return deletedOnString;
+}
+
 QString ASObject::isLiked()
 {
     return this->liked;
@@ -443,3 +459,78 @@ QVariantMap ASObject::getInReplyTo()
 {
     return this->inReplyToMap;
 }
+
+
+QString ASObject::personStringFromList(QVariantList variantList, int count)
+{
+    QString personString;
+
+    foreach (QVariant listItem, variantList)
+    {
+        QVariantMap itemMap = listItem.toMap();
+
+        QString name = itemMap.value("displayName").toString();
+        if (name.isEmpty())
+        {
+            name = ASPerson::cleanupId(itemMap.value("id").toString()); // fallback
+        }
+        QString profileUrl = itemMap.value("url").toString();
+
+        personString.prepend("<a href=\"" + profileUrl + "\">"
+                             + name + "</a>, "); // Reverse order
+    }
+
+    int remainingCount = count - variantList.size();
+
+    // Add "and $COUNT other"
+    if (count != -1 && remainingCount > 0)
+    {
+        if (remainingCount == 1)
+        {
+            personString.append(tr("and one other"));
+        }
+        else
+        {
+            personString.append(tr("and %1 others").arg(remainingCount));
+        }
+    }
+    else
+    {
+        // Remove last comma and space
+        personString.remove(-2, 2);
+    }
+
+
+    return personString;
+}
+
+
+
+/*
+ * Returns true if objectType is one of the types that Post() can display
+ *
+ *
+ */
+bool ASObject::canDisplayObject(QString objectType)
+{
+    bool canDisplay = false;
+
+    if (objectType == "note"
+     || objectType == "article"
+     || objectType == "image"
+     || objectType == "audio"
+     || objectType == "video"
+     || objectType == "file"
+     || objectType == "comment"
+     || objectType == "group")
+    {
+        canDisplay = true;
+    }
+    else
+    {
+        qDebug() << "ASObject::canDisplayObject() - Unsupported:"
+                 << objectType;
+    }
+
+    return canDisplay;
+}
