@@ -27,6 +27,8 @@
 #include <QDebug>
 
 #include "asperson.h"
+#include "timestamp.h"
+
 
 class ASObject : public QObject
 {
@@ -51,6 +53,7 @@ public:
     QString getLocationTooltip();
 
     QString getDeletedTime();
+    QString getDeletedOnString();
     QString isLiked();
 
     QString getTitle();
@@ -82,6 +85,12 @@ public:
     QVariantMap getOriginalObject();
     QVariantMap getInReplyTo();
 
+    static QString personStringFromList(QVariantList variantList,
+                                        int count=-1);
+
+    static bool canDisplayObject(QString objectType);
+
+
 signals:
 
 public slots:
