@@ -68,6 +68,18 @@ QString ASPerson::getName()
     return name;
 }
 
+QString ASPerson::getNameWithFallback()
+{
+    if (!name.isEmpty())
+    {
+        return name;
+    }
+    else
+    {
+        return id;
+    }
+}
+
 QString ASPerson::getHometown()
 {
     return hometown;
