@@ -33,11 +33,12 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     }
     else
     {
-        titlePart = tr("'CC' List");
+        titlePart = tr("'Cc' List");
     }
 
     this->setWindowTitle(titlePart + " - Dianara");
-    this->setWindowIcon(QIcon::fromTheme("system-users"));
+    this->setWindowIcon(QIcon::fromTheme("system-users",
+                                         QIcon(":/images/no-avatar.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::WindowModal);
     this->setMinimumSize(440, 340);
@@ -83,7 +84,8 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     selectedListWidget->setSelectionMode(QListView::ExtendedSelection);
     selectedListWidget->setIconSize(QSize(48, 48));
 
-    this->clearSelectedListButton = new QPushButton(QIcon::fromTheme("edit-clear-list"),
+    this->clearSelectedListButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
+                                                                     QIcon(":/images/button-delete.png")),
                                                     tr("Clear &List"));
     connect(clearSelectedListButton, SIGNAL(clicked()),
             selectedListWidget, SLOT(clear()));
@@ -98,6 +100,8 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
                                    tr("&Cancel"));
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(close()));
+
+
     buttonsLayout = new QHBoxLayout();
     buttonsLayout->setAlignment(Qt::AlignRight);
     buttonsLayout->addWidget(doneButton);
@@ -120,6 +124,25 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     mainLayout->addWidget(selectedListGroupbox, 4);
     this->setLayout(mainLayout);
 
+
+    // Ctrl+Enter is the same as the "Done" button
+    doneAction = new QAction(this);
+    QList<QKeySequence> doneShortcuts;
+    doneShortcuts << QKeySequence("Ctrl+Return")
+                  << QKeySequence("Ctrl+Enter");
+    doneAction->setShortcuts(doneShortcuts);
+    connect(doneAction, SIGNAL(triggered()),
+            this, SLOT(setAudience()));
+    this->addAction(doneAction);
+
+    // ESC is the same as the "Cancel" button
+    cancelAction = new QAction(this);
+    cancelAction->setShortcut(Qt::Key_Escape);
+    connect(cancelAction, SIGNAL(triggered()),
+            this, SLOT(close()));
+    this->addAction(cancelAction);
+
+
     qDebug() << "AudienceSelector created" << titlePart;
 }
 
@@ -234,18 +257,6 @@ void AudienceSelector::setAudience()
 
 
 
-void AudienceSelector::keyPressEvent(QKeyEvent *event)
-{
-    if (event->key() == Qt::Key_Escape)
-    {
-        this->close();
-    }
-    else
-    {
-        event->accept();
-    }
-}
-
 void AudienceSelector::closeEvent(QCloseEvent *event)
 {
     this->resetLists();
