@@ -35,6 +35,7 @@ AvatarButton::AvatarButton(ASPerson *person,
                         "QToolButton:hover { border: none; "
                         "                    background-color: palette(highlight) }");
     this->setIconSize(avatarSize);
+    this->setMinimumSize(avatarSize);
     this->iconWidth = avatarSize.width();
 
     this->setToolTip(person->getTooltipInfo());
@@ -62,9 +63,8 @@ AvatarButton::AvatarButton(ASPerson *person,
     this->authorUrl = person->getUrl();
     this->authorAvatarUrl = person->getAvatar();
 
+    this->authorFollowed = false; // Real status will be read when creating the menu
 
-    // Get "following" status before creating avatar menu
-    this->authorFollowed = this->pController->userInFollowing(authorId);
 
     createAvatarMenu();
     if (!authorId.isEmpty())  // Don't add the menu for invalid users
@@ -139,7 +139,8 @@ void AvatarButton::createAvatarMenu()
     {
         openProfileString = tr("Open your profile in web browser");
     }
-    this->avatarMenuProfileAction = new QAction(QIcon::fromTheme("internet-web-browser"),
+    this->avatarMenuProfileAction = new QAction(QIcon::fromTheme("internet-web-browser",
+                                                                 QIcon(":/images/no-avatar.png")),
                                                  openProfileString, this);
     connect(avatarMenuProfileAction, SIGNAL(triggered()),
             this, SLOT(openAuthorProfileInBrowser()));
@@ -151,7 +152,7 @@ void AvatarButton::createAvatarMenu()
 
 
     this->avatarMenuFollowAction = new QAction("*follow/unfollow*", this);
-    // Connections and proper label come are set in setFollowUnfollow()
+    // Connections and proper label are set in setFollowUnfollow()
 
     this->avatarMenuMessageAction = new QAction(QIcon::fromTheme("document-edit",
                                                                  QIcon(":/images/button-edit.png")),
@@ -166,7 +167,7 @@ void AvatarButton::createAvatarMenu()
     if (!userIsAuthor)
     {
         avatarMenu->addAction(avatarMenuFollowAction);
-        this->setFollowUnfollow();
+        this->syncFollowState(true);
 
         avatarMenu->addAction(avatarMenuMessageAction);
     }
@@ -177,6 +178,23 @@ void AvatarButton::createAvatarMenu()
 }
 
 
+/*
+ * See if we're currently following this user, according to the contact list
+ *
+ */
+void AvatarButton::syncFollowState(bool firstTime)
+{
+    bool authorFollowedBefore = this->authorFollowed;
+
+    this->authorFollowed = this->pController->userInFollowing(authorId);
+
+    if (this->authorFollowed != authorFollowedBefore || firstTime)
+    {
+        this->setFollowUnfollow();
+    }
+}
+
+
 
 /*
  * Set the icon and text of the follow/unfollow option of the avatar menu
@@ -187,23 +205,25 @@ void AvatarButton::setFollowUnfollow()
 {
     if (this->authorFollowed)
     {
-        this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-remove-user"));
+        this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-remove-user",
+                                                               QIcon(":/images/list-remove.png")));
         this->avatarMenuFollowAction->setText(tr("Stop following"));
         connect(avatarMenuFollowAction, SIGNAL(triggered()),
                 this, SLOT(unfollowUser()));
         disconnect(avatarMenuFollowAction, SIGNAL(triggered()),
                    this, SLOT(followUser()));
-        qDebug() << "post author followed, connecting to UNFOLLOW()" << this->authorId;
+        //qDebug() << "post author followed, connecting to UNFOLLOW()" << this->authorId;
     }
     else
     {
-        this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-add-user"));
+        this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-add-user",
+                                                               QIcon(":/images/list-add.png")));
         this->avatarMenuFollowAction->setText(tr("Follow"));
         connect(avatarMenuFollowAction, SIGNAL(triggered()),
                 this, SLOT(followUser()));
         disconnect(avatarMenuFollowAction, SIGNAL(triggered()),
                    this, SLOT(unfollowUser()));
-        qDebug() << "post author not followed, connecting to FOLLOW()" << this->authorId;
+        //qDebug() << "post author not followed, connecting to FOLLOW()" << this->authorId;
     }
 }
 
@@ -233,9 +253,7 @@ void AvatarButton::openAuthorProfileInBrowser()
 void AvatarButton::followUser()
 {
     this->pController->followContact(this->authorId);
-
-    authorFollowed = true; // FIXME: should wait until confirmed by server...
-    this->setFollowUnfollow();
+    // Actual menu will be updated when appropriate SIGNAL is received
 }
 
 
@@ -249,9 +267,7 @@ void AvatarButton::unfollowUser()
     if (confirmation == 0)
     {
         this->pController->unfollowContact(this->authorId);
-
-        authorFollowed = false; // FIXME: should wait until confirmed by server...
-        this->setFollowUnfollow();
+        // Menu option will be updated when appropriate SIGNAL is received
     }
 }
 
