@@ -118,7 +118,7 @@ Comment::Comment(PumpController *pumpController,
     metadataFont.setBold(true);
     metadataFont.setItalic(false);
 
-    likeLabel = new QLabel("*like*");
+    likeLabel = new QLabel("*like*", this);
     likeLabel->setContextMenuPolicy(Qt::NoContextMenu);
     likeLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
     likeLabel->setFont(metadataFont);
@@ -140,7 +140,8 @@ Comment::Comment(PumpController *pumpController,
 
     quoteLabel = new QLabel("<a href=\"quote://\">"
                             + tr("Quote", "This is a verb, infinitive")
-                            + "</a>");
+                            + "</a>",
+                            this);
     quoteLabel->setContextMenuPolicy(Qt::NoContextMenu);
     quoteLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
     quoteLabel->setFont(metadataFont);
@@ -152,7 +153,9 @@ Comment::Comment(PumpController *pumpController,
             this, SLOT(quoteComment()));
 
 
-    editLabel = new QLabel("<a href=\"edit://\">" + tr("Edit") + "</a>");
+    editLabel = new QLabel("<a href=\"edit://\">"
+                           + tr("Edit")
+                           + "</a>", this);
     editLabel->setContextMenuPolicy(Qt::NoContextMenu);
     editLabel->setAlignment(Qt::AlignTop | Qt::AlignRight);
     editLabel->setFont(metadataFont);
@@ -162,7 +165,9 @@ Comment::Comment(PumpController *pumpController,
             this, SLOT(editComment()));
 
 
-    deleteLabel = new QLabel("<a href=\"delete://\">" + tr("Delete") + "</a>");
+    deleteLabel = new QLabel("<a href=\"delete://\">"
+                             + tr("Delete")
+                             + "</a>", this);
     deleteLabel->setContextMenuPolicy(Qt::NoContextMenu);
     deleteLabel->setAlignment(Qt::AlignTop | Qt::AlignRight);
     deleteLabel->setFont(metadataFont);
@@ -185,7 +190,7 @@ Comment::Comment(PumpController *pumpController,
     this->commentOriginalText = commentObject->getContent();
 
 
-    contentLabel = new QLabel();
+    contentLabel = new QLabel(this);
     contentLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     contentLabel->setFont(commentsFont);
     contentLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
@@ -224,6 +229,12 @@ Comment::Comment(PumpController *pumpController,
         rightTopLayout->addWidget(editLabel,   0, Qt::AlignRight);
         rightTopLayout->addWidget(deleteLabel, 0, Qt::AlignRight);
     }
+    else
+    {
+        // Since these widgets are initialized with a parent, hide them when not needed
+        editLabel->hide();
+        deleteLabel->hide();
+    }
 
     rightLayout = new QVBoxLayout();
     rightLayout->addLayout(rightTopLayout, 0);
@@ -256,46 +267,43 @@ void Comment::fixLikeLabelText()
 {
     if (commentIsLiked)
     {
-        this->likeLabel->setText("<a href=\"unlike://\">" + tr("Unlike") +"</a>");
+        this->likeLabel->setText("<a href=\"unlike://\">"
+                                 + tr("Unlike")
+                                 +"</a>");
     }
     else
     {
-        this->likeLabel->setText("<a href=\"like://\">" + tr("Like") +"</a>");
+        this->likeLabel->setText("<a href=\"like://\">"
+                                 + tr("Like")
+                                 +"</a>");
     }
 }
 
 
 void Comment::setLikesCount(QString count, QVariantList namesVariantList)
 {
+    // FIXME: count should be int
     if (count != "0")
     {
-        QString likesString;  // FIXME: repeated in Post(), move to method
-        foreach (QVariant likesMap, namesVariantList)
-        {
-            QString name = likesMap.toMap().value("displayName").toString();
-            if (name.isEmpty())
-            {
-                name = ASPerson::cleanupId(likesMap.toMap()
-                                                   .value("id")
-                                                   .toString()); // fallback
-            }
-            likesString.append(name + ", ");
-        }
-        likesString.remove(-2, 2); // remove last comma+space: ", "
+        QString likesString = ASObject::personStringFromList(namesVariantList,
+                                                             count.toInt());
+
         if (count == "1")
         {
             likesString = tr("%1 likes this comment",
-                             "Singular: %1=name of just 1 person").arg(likesString);
+                             "Singular: %1=name of just "
+                             "1 person").arg(likesString);
         }
         else // several people
         {
             likesString = tr("%1 like this comment",
-                             "Plural: %1=list of people like John, Jane, Smith").arg(likesString);
+                             "Plural: %1=list of people like John, "
+                             "Jane, Smith").arg(likesString);
         }
 
 
-        likesCountLabel->setText(QString::fromUtf8("\342\231\245")  // heart symbol
-                                 + QString(" %1").arg(count));
+        likesCountLabel->setBaseText(QString::fromUtf8("\342\231\245")  // Heart symbol
+                                   + QString(" %1").arg(count));
         // set tooltip as HTML, so it gets wordwrapped
         likesCountLabel->setToolTip("<b></b>" + likesString);
         likesCountLabel->show();
@@ -317,7 +325,12 @@ void Comment::setFuzzyTimestamps()
         timestamp.prepend("**"); // FIXME, somehow show edit time
     }
 
-    this->timestampLabel->setText(timestamp);
+    this->timestampLabel->setBaseText(timestamp);
+}
+
+void Comment::syncAvatarFollowState()
+{
+    this->avatarButton->syncFollowState();
 }
 
 
