@@ -28,8 +28,9 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     this->globalObj = globalObject;
     this->editingMode = false;
 
+    this->reloadCommentsString = tr("Reload comments");
     this->showAllCommentsLinkLabel = new QLabel("<a href=\"showall://\">"
-                                                + tr("Show All Comments")
+                                                + reloadCommentsString
                                                 + "</a>");
     showAllCommentsLinkLabel->setContextMenuPolicy(Qt::NoContextMenu);
     QFont showAllFont;
@@ -38,6 +39,7 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     connect(showAllCommentsLinkLabel, SIGNAL(linkActivated(QString)),
             this, SLOT(requestAllComments()));
 
+    this->setContentsMargins(0, 0, 0, 0);
 
     commentsLayout = new QVBoxLayout();
     commentsLayout->setAlignment(Qt::AlignTop);
@@ -123,6 +125,7 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
     bottomLayout = new QGridLayout();
     bottomLayout->setContentsMargins(0, 0, 0, 0);
+    bottomLayout->setSpacing(1);
     bottomLayout->addWidget(commentComposer,        0, 0, 4, 3);
     bottomLayout->addWidget(toolsButton,            0, 3, 1, 1);
     bottomLayout->addWidget(statusInfoLabel,        1, 3, 1, 1, Qt::AlignCenter);
@@ -131,6 +134,7 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
     mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setSpacing(1);
     mainLayout->addWidget(showAllCommentsLinkLabel, 0, Qt::AlignRight | Qt::AlignTop);
     mainLayout->addWidget(commentsScrollArea,       3);
     mainLayout->addLayout(bottomLayout,             0);
@@ -168,6 +172,23 @@ void CommenterBlock::setComments(QVariantList commentsList, int commentCount)
 
     if (commentCount > 0)
     {
+        QString showAllString;
+        if (commentCount > commentsList.size())
+        {
+            showAllString = tr("Show all %1 comments").arg(commentCount);
+        }
+        else
+        {
+            showAllString = this->reloadCommentsString;
+        }
+
+        // Small trick to avoid a bug where the link stops having appropriate mouse pointer
+        this->showAllCommentsLinkLabel->clear();
+        this->showAllCommentsLinkLabel->hide();
+
+        this->showAllCommentsLinkLabel->setText("<a href=\"showall://\">"
+                                                + showAllString
+                                                + "</a>");
         this->showAllCommentsLinkLabel->show();
 
         //this->adjustCommentsWidth();
@@ -198,7 +219,7 @@ void CommenterBlock::setComments(QVariantList commentsList, int commentCount)
         // Then, some msecs later, try again, in case there was no scrollbar before,
         // and the first try didn't work
         // Trying immediately first avoids a flicker-like effect sometimes
-        scrollToBottomTimer->start(100);
+        scrollToBottomTimer->start(500);
     }
 }
 
@@ -211,6 +232,14 @@ void CommenterBlock::updateFuzzyTimestamps()
     }
 }
 
+void CommenterBlock::updateAvatarFollowStates()
+{
+    foreach (Comment *comment, this->commentsInBlock)
+    {
+        comment->syncAvatarFollowState();
+    }
+}
+
 
 
 void CommenterBlock::adjustCommentsWidth()
@@ -256,7 +285,8 @@ void CommenterBlock::setMinimumMode()
         this->editingMode = false;
         this->editingCommentId.clear();
 
-        this->commentButton->setText(tr("Comment")); // Button text back to "Comment" as usual
+        this->commentButton->setText(tr("Comment",  // Button text back to "Comment" as usual
+                                        "Infinitive verb")); // With exact same comment, so it's 1 entry
     }
 
     // Unblock updates to timeline, since we're done commenting
@@ -292,7 +322,7 @@ void CommenterBlock::setFullMode(QString initialText)
 void CommenterBlock::quoteComment(QString content)
 {
     this->setFullMode();
-    this->commentComposer->append(content);
+    this->commentComposer->append(content); // FIXME 1.3: redundant? could call setFullMode(content)
 }
 
 
@@ -322,7 +352,7 @@ void CommenterBlock::editComment(QString id, QString content)
 
 void CommenterBlock::requestAllComments()
 {
-    emit allCommentsRequested();
+    emit allCommentsRequested(); // FIXME 1.3: could connect() to this signal directly
 }
 
 
