@@ -31,12 +31,14 @@ Composer::Composer(bool forPublisher)
     QFont startConversationFont;
     startConversationFont.setPointSize(startConversationFont.pointSize() - 2);
 
-    startConversationLabel = new QLabel(tr("Click here or press Control+N to post a note..."));
+    startConversationLabel = new QLabel(tr("Click here or press Control+N "
+                                           "to post a note..."),
+                                        this);
     startConversationLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     startConversationLabel->setFont(startConversationFont);
 
     // A menu to insert some Unicode symbols
-    symbolsMenu = new QMenu(tr("Symbols"));
+    symbolsMenu = new QMenu(tr("Symbols"), this);
     symbolsMenu->setIcon(QIcon::fromTheme("character-set"));
     symbolsMenu->addAction(QString::fromUtf8("\342\230\272")); // Smiling face
     symbolsMenu->addAction(QString::fromUtf8("\342\230\271")); // Sad face
@@ -54,7 +56,7 @@ Composer::Composer(bool forPublisher)
             this, SLOT(insertSymbol(QAction*)));
 
 
-    toolsMenu = new QMenu(tr("Formatting"));
+    toolsMenu = new QMenu(tr("Formatting"), this);
     toolsMenu->addAction(QIcon::fromTheme(""),
                          tr("Normal"),
                          this,
@@ -90,6 +92,10 @@ Composer::Composer(bool forPublisher)
                          tr("List"),
                          this,
                          SLOT(makeList()));
+    toolsMenu->addAction(QIcon::fromTheme("insert-table"),
+                         tr("Table"),
+                         this,
+                         SLOT(makeTable()));
     toolsMenu->addAction(QIcon::fromTheme("format-justify-fill"),
                          tr("Preformatted block"),
                          this,
@@ -122,11 +128,13 @@ Composer::Composer(bool forPublisher)
     toolsMenu->addMenu(symbolsMenu);
 
 
-    toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered"),
+    toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered",
+                                                   QIcon(":/images/button-configure.png")),
                                   tr("&Format",
                                      "Button for text formatting and related options"));
     toolsButton->setMenu(toolsMenu);
-    toolsButton->setToolTip(tr("Text Formatting Options"));
+    toolsButton->setToolTip("<b></b>"
+                            + tr("Text Formatting Options"));
 
 
     // Extra action for the context menu, paste as plaintext
@@ -140,19 +148,24 @@ Composer::Composer(bool forPublisher)
 
     // Add action to this object, in order for the shortcut to work
     // Otherwise, the action isn't available until the context menu is present
-    this->addAction(pastePlaintextAction);
+    this->addAction(pastePlaintextAction); // FIXME QAction::eventFilter:
+                                           // Ambiguous shortcut overload: Ctrl+Shift+V
 
     mainLayout = new QHBoxLayout();
 
     if (this->forPublisher)  // Publisher mode
     {
-        this->setToolTip(tr("Type a message here to post it"));
+        this->setToolTip("<b></b>"
+                         + tr("Type a message here to post it"));
 
         mainLayout->addWidget(startConversationLabel, 1, Qt::AlignLeft | Qt::AlignVCenter);
     }
     else                     // or Commenter mode
     {
-        this->setToolTip(tr("Type a comment here"));
+        this->setToolTip("<b></b>"
+                         + tr("Type a comment here"));
+
+        startConversationLabel->hide(); // Since it has a parent but it's not used, hide it
     }
     this->setLayout(mainLayout);
 
@@ -180,13 +193,23 @@ void Composer::erase()
 
 void Composer::insertLink(QString url, QString title)
 {
+    bool prettyLink = true;
     if (title.isEmpty())
     {
+        prettyLink = false;
         title = url;
     }
 
     this->insertHtml("<a href=\"" + url + "\">"
-                     + title + "</a> "); // Important, space after!
+                     + title + "</a>");
+
+    // Space after, when there's no text after the link,
+    // or the link is inserted without selecting text before,
+    // so what the user types next is regular text
+    if (this->textCursor().atEnd() || !prettyLink)
+    {
+        this->insertHtml("&nbsp;");
+    }
 }
 
 int Composer::getMessageLabelHeight()
@@ -302,7 +325,30 @@ void Composer::insertFromMimeData(const QMimeData *source)
     if (pastedText.startsWith("http://")
      || pastedText.startsWith("https://"))
     {
-        this->insertLink(pastedText);
+        int insertionType = 1;
+
+        if (pastedText.endsWith(".png", Qt::CaseInsensitive)
+         || pastedText.endsWith(".jpg", Qt::CaseInsensitive)
+         || pastedText.endsWith(".jpeg", Qt::CaseInsensitive)
+         || pastedText.endsWith(".gif", Qt::CaseInsensitive))
+        {
+            insertionType = QMessageBox::question(this,
+                                         tr("Insert as image?"),
+                                         tr("The link you are pasting seems to "
+                                            "point to an image.") + "\n",
+                                         tr("Insert as visible image"), // Default option (enter)
+                                         tr("Insert as link"),  // ESC option
+                                         "", 0, 1);
+        }
+
+        if (insertionType == 0) // Default button, insert as image
+        {
+            this->insertHtml("<img src=\"" + pastedText + "\" />");
+        }
+        else
+        {
+            this->insertLink(pastedText);
+        }
     }
     else // Just paste original contents
     {
@@ -429,6 +475,45 @@ void Composer::makeList()
 }
 
 
+void Composer::makeTable()
+{
+    const QString dialogTitle = tr("Table Size");
+
+    bool inputOk = false;
+    int rows = QInputDialog::getInt(this, dialogTitle,
+                                    tr("How many rows (height)?")
+                                    + "       " // Make the dialog a little wider than necessary
+                                    + QString::fromUtf8("\342\207\225") // up-down arrow
+                                    + "\n\n",
+                                    5,
+                                    1, 10,
+                                    1, &inputOk);
+
+    if (inputOk) // Rows dialog wasn't cancelled
+    {
+        int columns = QInputDialog::getInt(this, dialogTitle,
+                                           tr("How many columns (width)?")
+                                           + "       "
+                                           + QString::fromUtf8("\342\207\224") // left-right arrow
+                                           + "\n\n",
+                                           4,
+                                           1, 10,
+                                           1, &inputOk);
+
+        if (inputOk) // Columns dialog wasn't cancelled either
+        {
+            QTextTableFormat tableFormat;
+            tableFormat.setCellPadding(2);
+            tableFormat.setCellSpacing(4);
+
+            this->textCursor().insertTable(rows, columns, tableFormat);
+        }
+    }
+
+    this->setFocus();
+}
+
+
 
 /*
  * Put selected text into a <pre> block
@@ -529,22 +614,22 @@ void Composer::insertImage()
 {
     // FIXME: should make sure there is no text selected
 
-    QString imageURL;
-    imageURL = QInputDialog::getText(this,
-                                     tr("Insert an image from a URL"),
-                                     tr("Type or paste the image address here.\n"
-                                        "The link must point to the image file directly.")
-                                     + "\n\n",
-                                     QLineEdit::Normal,
-                                     "http://");
+    QString imageUrl;
+    imageUrl = QInputDialog::getText(this,
+                             tr("Insert an image from a URL"),
+                             tr("Type or paste the image address here.\n"
+                                "The link must point to the image file directly.")
+                             + "\n\n",
+                             QLineEdit::Normal,
+                             "http://");
 
 
-    if (!imageURL.isEmpty())
+    if (!imageUrl.isEmpty())
     {
-        if (imageURL.startsWith("http://")
-         || imageURL.startsWith("https://"))
+        if (imageUrl.startsWith("http://")
+         || imageUrl.startsWith("https://"))
         {
-            this->insertHtml("<img src=\"" + imageURL + "\" />");
+            this->insertHtml("<img src=\"" + imageUrl + "\" />");
         }
         else
         {
@@ -552,7 +637,7 @@ void Composer::insertImage()
                                  tr("The address you entered (%1) "
                                     "is not valid.\n"
                                     "Image addresses should begin "
-                                    "with http:// or https://").arg(imageURL));
+                                    "with http:// or https://").arg(imageUrl));
         }
     }
     else
