@@ -35,7 +35,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                          QIcon(":/images/button-configure.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
-    this->setMinimumSize(560, 420);
+    this->setMinimumSize(640, 520);
 
     QSettings settings;
     QSize savedWindowsize = settings.value("ConfigDialog/configWindowSize").toSize();
@@ -60,7 +60,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     //////////////////////////////////////////////////////////////// Upper part
 
-    // Tab 1, general options
+    // Page 1, general options
     this->generalOptionsLayout = new QFormLayout();
 
     updateIntervalSpinbox = new QSpinBox();
@@ -70,21 +70,16 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     generalOptionsLayout->addRow(tr("Timeline &update interval"),
                                  updateIntervalSpinbox);
 
-    postsPerPageMainSpinbox = new QSpinBox();
-    postsPerPageMainSpinbox->setRange(5, 100); // 5-100 ppp
-    postsPerPageMainSpinbox->setSuffix(" "+ tr("posts",
-                                               "Goes after a number, as: 25 posts"));
-    postsPerPageMainSpinbox->setValue(postsPerPageMain);
-    generalOptionsLayout->addRow(tr("&Posts per page, main timeline"),
-                                 postsPerPageMainSpinbox);
 
-    postsPerPageOtherSpinbox = new QSpinBox();
-    postsPerPageOtherSpinbox->setRange(1, 100); // 1-100 ppp
-    postsPerPageOtherSpinbox->setSuffix(" "+ tr("posts",
-                                                "This goes after a number, like: 10 posts"));
-    postsPerPageOtherSpinbox->setValue(postsPerPageOther);
-    generalOptionsLayout->addRow(tr("Posts per page, &other timelines"),
-                                 postsPerPageOtherSpinbox);
+    publicPostsCheckbox = new QCheckBox();
+    publicPostsCheckbox->setChecked(publicPosts);
+    generalOptionsLayout->addRow(tr("Public posts as &default"),
+                                 publicPostsCheckbox);
+
+    // ------------------------------------------------
+    QFrame *lineFrame1 = new QFrame();
+    lineFrame1->setFrameStyle(QFrame::HLine);
+    generalOptionsLayout->addRow(lineFrame1);
 
 
     tabsPositionCombobox = new QComboBox();
@@ -107,18 +102,14 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                  tabsMovableCheckbox);
 
 
-    publicPostsCheckbox = new QCheckBox();
-    publicPostsCheckbox->setChecked(publicPosts);
-    generalOptionsLayout->addRow(tr("Public posts as &default"),
-                                 publicPostsCheckbox);
+    // ------------------------------------------------
+    QFrame *lineFrame2 = new QFrame();
+    lineFrame2->setFrameStyle(QFrame::HLine);
+    generalOptionsLayout->addRow(lineFrame2);
 
 
-    QFrame *lineFrame1 = new QFrame();
-    lineFrame1->setFrameStyle(QFrame::HLine);
-    generalOptionsLayout->addRow(lineFrame1);
-
-
-    proxyConfigButton = new QPushButton(QIcon::fromTheme("preferences-system-network"),
+    proxyConfigButton = new QPushButton(QIcon::fromTheme("preferences-system-network",
+                                                         QIcon(":/images/button-configure.png")),
                                         tr("Pro&xy Settings"));
     connect(proxyConfigButton, SIGNAL(clicked()),
             proxyDialog, SLOT(show()));
@@ -133,34 +124,13 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     generalOptionsLayout->addRow(tr("Filtering rules"),
                                  filterEditorButton);
 
-    QFrame *lineFrame2 = new QFrame();
-    lineFrame2->setFrameStyle(QFrame::HLine);
-    generalOptionsLayout->addRow(lineFrame2);
-
-
-    minorFeedSnippetsCombobox = new QComboBox();
-    minorFeedSnippetsCombobox->addItem(tr("Highlighted activities, except mine"));
-    minorFeedSnippetsCombobox->addItem(tr("Any highlighted activity"));
-    minorFeedSnippetsCombobox->addItem(tr("Always"));
-    minorFeedSnippetsCombobox->addItem(tr("Never"));
-    minorFeedSnippetsCombobox->setCurrentIndex(globalObj->getMinorFeedSnippetsType());
-    generalOptionsLayout->addRow(tr("Show snippets in minor feed"),
-                                 minorFeedSnippetsCombobox);
-
-    snippetLimitSpinbox = new QSpinBox();
-    snippetLimitSpinbox->setRange(10, 10000);
-    snippetLimitSpinbox->setSuffix(" " + tr("characters",
-                                            "This is a suffix, after a number"));
-    snippetLimitSpinbox->setValue(globalObj->getSnippetsCharLimit());
-    generalOptionsLayout->addRow(tr("Snippet limit"),
-                                 snippetLimitSpinbox);
 
     generalOptionsWidget = new QWidget();
     generalOptionsWidget->setLayout(generalOptionsLayout);
 
 
 
-    // Tab 2, fonts
+    // Page 2, fonts
     this->fontOptionsLayout = new QVBoxLayout();
     fontPicker1 = new FontPicker(tr("Post Titles"),
                                  globalObj->getPostTitleFont());
@@ -171,6 +141,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     fontPicker4 = new FontPicker(tr("Minor Feed"),
                                  globalObj->getMinorFeedFont());
     // FIXME: more for "Timestamps" or something else?
+    // FIXME: add a "base font size" option
 
     fontOptionsLayout->addWidget(fontPicker1);
     fontOptionsLayout->addWidget(fontPicker2);
@@ -183,7 +154,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
 
-    // Tab 3, colors
+    // Page 3, colors
     this->colorOptionsLayout = new QVBoxLayout();
 
     QStringList colorList = globalObj->getColorsList();
@@ -230,7 +201,63 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
 
-    // Tab 4, notification and systray icon options
+    // Page 4, timelines options
+    timelinesOptionsLayout = new QFormLayout();
+
+    postsPerPageMainSpinbox = new QSpinBox();
+    postsPerPageMainSpinbox->setRange(5, 50); // 5-50 ppp
+    postsPerPageMainSpinbox->setSuffix(" "+ tr("posts",
+                                               "Goes after a number, as: "
+                                               "25 posts"));
+    postsPerPageMainSpinbox->setValue(postsPerPageMain);
+    timelinesOptionsLayout->addRow(tr("&Posts per page, main timeline"),
+                                   postsPerPageMainSpinbox);
+
+    postsPerPageOtherSpinbox = new QSpinBox();
+    postsPerPageOtherSpinbox->setRange(1, 30); // 1-30 ppp
+    postsPerPageOtherSpinbox->setSuffix(" "+ tr("posts",
+                                                "This goes after a number, "
+                                                "like: 10 posts"));
+    postsPerPageOtherSpinbox->setValue(postsPerPageOther);
+    timelinesOptionsLayout->addRow(tr("Posts per page, &other timelines"),
+                                   postsPerPageOtherSpinbox);
+
+    minorFeedSnippetsCombobox = new QComboBox();
+    minorFeedSnippetsCombobox->addItem(tr("Highlighted activities, except mine"));
+    minorFeedSnippetsCombobox->addItem(tr("Any highlighted activity"));
+    minorFeedSnippetsCombobox->addItem(tr("Always"));
+    minorFeedSnippetsCombobox->addItem(tr("Never"));
+    minorFeedSnippetsCombobox->setCurrentIndex(globalObj->getMinorFeedSnippetsType());
+    timelinesOptionsLayout->addRow(tr("Show snippets in minor feed"),
+                                   minorFeedSnippetsCombobox);
+
+    snippetLimitSpinbox = new QSpinBox();
+    snippetLimitSpinbox->setRange(10, 10000);
+    snippetLimitSpinbox->setSuffix(" " + tr("characters",
+                                            "This is a suffix, after a number"));
+    snippetLimitSpinbox->setValue(globalObj->getSnippetsCharLimit());
+    timelinesOptionsLayout->addRow(tr("Snippet limit"),
+                                   snippetLimitSpinbox);
+
+    timelinesOptionsWidget = new QWidget();
+    timelinesOptionsWidget->setLayout(timelinesOptionsLayout);
+
+
+
+    // Page 5, posts options
+    showExtraInfoCheckbox = new QCheckBox();
+    showExtraInfoCheckbox->setChecked(globalObj->getPostShowExtraInfo());
+
+    postsOptionsLayout = new QFormLayout();
+    postsOptionsLayout->addRow(tr("Show extra information"),
+                               showExtraInfoCheckbox);
+
+    postsOptionsWidget = new QWidget();
+    postsOptionsWidget->setLayout(postsOptionsLayout);
+
+
+
+    // Page 6, notifications options
     notificationOptionsLayout = new QFormLayout();
 
     notificationStyleCombobox = new QComboBox();
@@ -269,10 +296,13 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     this->syncNotifierOptions();
 
-    QFrame *lineFrame3 = new QFrame();
-    lineFrame3->setFrameStyle(QFrame::HLine);
-    lineFrame3->setMinimumHeight(16);
-    notificationOptionsLayout->addRow(lineFrame3);
+    notificationOptionsWidget = new QWidget();
+    notificationOptionsWidget->setLayout(notificationOptionsLayout);
+
+
+
+    // Page 7, systray options
+    systrayOptionsLayout = new QFormLayout();
 
     systrayIconTypeCombobox = new QComboBox();
     systrayIconTypeCombobox->addItem(tr("Default"));
@@ -280,9 +310,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     systrayIconTypeCombobox->addItem(tr("Show your current avatar"));
     systrayIconTypeCombobox->addItem(tr("Custom icon"));
     systrayIconTypeCombobox->setCurrentIndex(settings.value("systrayIconType", 0).toInt());
-    notificationOptionsLayout->addRow(tr("System Tray Icon &Type"),
-                                      systrayIconTypeCombobox);
-
+    systrayOptionsLayout->addRow(tr("System Tray Icon &Type"),
+                                 systrayIconTypeCombobox);
 
     systrayCustomIconButton = new QPushButton(tr("S&elect..."));
     systrayCustomIconFN = settings.value("systrayCustomIconFN").toString();
@@ -298,12 +327,11 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     }
     connect(systrayCustomIconButton, SIGNAL(clicked()),
             this, SLOT(pickCustomIconFile()));
-    notificationOptionsLayout->addRow(tr("Custom &Icon"),
-                                      systrayCustomIconButton);
+    systrayOptionsLayout->addRow(tr("Custom &Icon"),
+                                 systrayCustomIconButton);
 
-
-    notificationOptionsWidget = new QWidget();
-    notificationOptionsWidget->setLayout(notificationOptionsLayout);
+    systrayOptionsWidget = new QWidget();
+    systrayOptionsWidget->setLayout(systrayOptionsLayout);
 
     settings.endGroup();
 
@@ -327,13 +355,26 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     categoriesListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
     categoriesListWidget->addItem(tr("General Options"));
-    categoriesListWidget->item(0)->setIcon(QIcon::fromTheme("preferences-other"));
+    categoriesListWidget->item(0)->setIcon(QIcon::fromTheme("preferences-other",
+                                                            QIcon(":/images/button-configure.png")));
     categoriesListWidget->addItem(tr("Fonts"));
-    categoriesListWidget->item(1)->setIcon(QIcon::fromTheme("preferences-desktop-font"));
+    categoriesListWidget->item(1)->setIcon(QIcon::fromTheme("preferences-desktop-font",
+                                                            QIcon(":/images/button-configure.png")));
     categoriesListWidget->addItem(tr("Colors"));
-    categoriesListWidget->item(2)->setIcon(QIcon::fromTheme("preferences-desktop-color"));
-    categoriesListWidget->addItem(tr("Notifications and System Tray"));
-    categoriesListWidget->item(3)->setIcon(QIcon::fromTheme("preferences-desktop-notification"));
+    categoriesListWidget->item(2)->setIcon(QIcon::fromTheme("preferences-desktop-color",
+                                                            QIcon(":/images/button-configure.png")));
+    categoriesListWidget->addItem(tr("Timelines"));
+    categoriesListWidget->item(3)->setIcon(QIcon::fromTheme("view-list-details",
+                                                            QIcon(":/images/feed-inbox.png")));
+    categoriesListWidget->addItem(tr("Posts"));
+    categoriesListWidget->item(4)->setIcon(QIcon::fromTheme("mail-message",
+                                                            QIcon(":/images/button-post.png")));
+    categoriesListWidget->addItem(tr("Notifications"));
+    categoriesListWidget->item(5)->setIcon(QIcon::fromTheme("preferences-desktop-notification",
+                                                            QIcon(":/images/button-online.png")));
+    categoriesListWidget->addItem(tr("System Tray"));     // dashboard-show ?
+    categoriesListWidget->item(6)->setIcon(QIcon::fromTheme("configure-toolbars",
+                                                            QIcon(":/images/button-configure.png")));
 
     categoriesStackedWidget = new QStackedWidget();
     categoriesStackedWidget->setSizePolicy(QSizePolicy::Preferred,
@@ -341,7 +382,10 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     categoriesStackedWidget->addWidget(generalOptionsWidget);
     categoriesStackedWidget->addWidget(fontOptionsWidget);
     categoriesStackedWidget->addWidget(colorOptionsWidget);
+    categoriesStackedWidget->addWidget(timelinesOptionsWidget);
+    categoriesStackedWidget->addWidget(postsOptionsWidget);
     categoriesStackedWidget->addWidget(notificationOptionsWidget);
+    categoriesStackedWidget->addWidget(systrayOptionsWidget);
 
     connect(categoriesListWidget, SIGNAL(currentRowChanged(int)),
             categoriesStackedWidget, SLOT(setCurrentIndex(int)));
@@ -435,24 +479,13 @@ void ConfigDialog::saveConfiguration()
     QSettings settings;
     settings.beginGroup("Configuration");
 
+    // General
     settings.setValue("updateInterval", this->updateIntervalSpinbox->value());
-
-    settings.setValue("postsPerPageMain",  this->postsPerPageMainSpinbox->value());
-    settings.setValue("postsPerPageOther", this->postsPerPageOtherSpinbox->value());
+    settings.setValue("publicPosts", this->publicPostsCheckbox->isChecked());
 
     settings.setValue("tabsPosition", this->tabsPositionCombobox->currentIndex());
     settings.setValue("tabsMovable",  this->tabsMovableCheckbox->isChecked());
 
-    settings.setValue("publicPosts", this->publicPostsCheckbox->isChecked());
-
-    settings.setValue("minorFeedSnippets",
-                      this->minorFeedSnippetsCombobox->currentIndex());
-    settings.setValue("snippetsCharLimit",
-                      this->snippetLimitSpinbox->value());
-
-    this->globalObj->syncGeneralSettings(this->minorFeedSnippetsCombobox->currentIndex(),
-                                         this->snippetLimitSpinbox->value());
-
 
     // Fonts
     settings.setValue("font1", this->fontPicker1->getFontInfo());
@@ -482,14 +515,33 @@ void ConfigDialog::saveConfiguration()
     this->globalObj->syncColorSettings(highlightColorsList);
 
 
-    // Notifications and tray
-    settings.setValue("showNotifications", this->notificationStyleCombobox->currentIndex());
+    // Timelines
+    settings.setValue("postsPerPageMain",  this->postsPerPageMainSpinbox->value());
+    settings.setValue("postsPerPageOther", this->postsPerPageOtherSpinbox->value());
+    settings.setValue("minorFeedSnippets",
+                      this->minorFeedSnippetsCombobox->currentIndex());
+    settings.setValue("snippetsCharLimit",
+                      this->snippetLimitSpinbox->value());
+
+    this->globalObj->syncTimelinesSettings(this->minorFeedSnippetsCombobox->currentIndex(),
+                                           this->snippetLimitSpinbox->value());
+
+    // Posts
+    settings.setValue("postShowExtraInfo",
+                      this->showExtraInfoCheckbox->isChecked());
+    this->globalObj->syncPostSettings(this->showExtraInfoCheckbox->isChecked());
+
+
+    // Notifications
+    settings.setValue("showNotifications",
+                      this->notificationStyleCombobox->currentIndex());
     settings.setValue("notifyNewTL", this->notifyNewTLCheckbox->isChecked());
     settings.setValue("notifyHLTL",  this->notifyHLTLCheckbox->isChecked());
     settings.setValue("notifyNewMW", this->notifyNewMWCheckbox->isChecked());
     settings.setValue("notifyHLMW",  this->notifyHLMWCheckbox->isChecked());
     this->syncNotifierOptions();
 
+    // Tray
     settings.setValue("systrayIconType", this->systrayIconTypeCombobox->currentIndex());
     settings.setValue("systrayCustomIconFN", this->systrayCustomIconFN);
 
