@@ -98,20 +98,15 @@ private:
     QFormLayout *generalOptionsLayout;
 
     QSpinBox *updateIntervalSpinbox;
-    QSpinBox *postsPerPageMainSpinbox;
-    QSpinBox *postsPerPageOtherSpinbox;
+    QCheckBox *publicPostsCheckbox;
     QComboBox *tabsPositionCombobox;
     QCheckBox *tabsMovableCheckbox;
-    QCheckBox *publicPostsCheckbox;
 
     QPushButton *proxyConfigButton;
     ProxyDialog *proxyDialog;
 
     QPushButton *filterEditorButton;
 
-    QComboBox *minorFeedSnippetsCombobox;
-    QSpinBox *snippetLimitSpinbox;
-
 
     // Page 2, fonts
     QWidget *fontOptionsWidget;
@@ -135,7 +130,25 @@ private:
     ColorPicker *colorPicker6;
 
 
-    // Page 4, notification and systray icon options
+    // Page 4, timelines options
+    QWidget *timelinesOptionsWidget;
+    QFormLayout *timelinesOptionsLayout;
+
+    QSpinBox *postsPerPageMainSpinbox;
+    QSpinBox *postsPerPageOtherSpinbox;
+
+    QComboBox *minorFeedSnippetsCombobox;
+    QSpinBox *snippetLimitSpinbox;
+
+
+    // Page 5, posts options
+    QWidget *postsOptionsWidget;
+    QFormLayout *postsOptionsLayout;
+
+    QCheckBox *showExtraInfoCheckbox;
+
+
+    // Page 6, notifications options
     QWidget *notificationOptionsWidget;
     QFormLayout *notificationOptionsLayout;
 
@@ -145,9 +158,13 @@ private:
     QCheckBox *notifyNewMWCheckbox;
     QCheckBox *notifyHLMWCheckbox;
 
+
+    // Page 7, system tray options
+    QWidget *systrayOptionsWidget;
+    QFormLayout *systrayOptionsLayout;
+
     QComboBox *systrayIconTypeCombobox;
     QPushButton *systrayCustomIconButton;
-
     QString systrayCustomIconFN;
 
 
