@@ -149,14 +149,14 @@ ContactCard::ContactCard(PumpController *pumpController,
     connect(sendMessageAction, SIGNAL(triggered()),
             this, SLOT(setMessagingModeForContact()));
 
-    addToListMenu = new QMenu(tr("In Lists..."));
+    addToListMenu = new QMenu(tr("In Lists..."), this);
     addToListMenu->setIcon(QIcon::fromTheme("format-list-unordered"));
     addToListMenu->addAction("fake list 1")->setCheckable(true); // FIXME...
     addToListMenu->addAction("fake list 2")->setCheckable(true);
     addToListMenu->addAction("fake list 3")->setCheckable(true);
 
 
-    optionsMenu = new QMenu("*options*");
+    optionsMenu = new QMenu("*options*", this);
     optionsMenu->addAction(openProfileAction);
     optionsMenu->addAction(sendMessageAction);
     //optionsMenu->addMenu(addToListMenu); // Don't include it for now, until 1.3 /FIXME
