@@ -38,6 +38,7 @@
 
 #include "mischelpers.h"
 #include "pumpcontroller.h"
+#include "globalobject.h"
 #include "asperson.h"
 #include "timestamp.h"
 
@@ -48,6 +49,7 @@ class ContactCard : public QFrame
 
 public:
     ContactCard(PumpController *pumpController,
+                GlobalObject *globalObject,
                 ASPerson *asPerson,
                 QWidget *parent = 0);
     ~ContactCard();
@@ -66,6 +68,7 @@ public slots:
     void unfollowContact();
 
     void openProfileInBrowser();
+    void setMessagingModeForContact();
 
     void redrawAvatar(QString avatarUrl, QString avatarFilename);
 
@@ -82,10 +85,12 @@ private:
     QPushButton *optionsButton;
     QMenu *optionsMenu;
     QAction *openProfileAction;
+    QAction *sendMessageAction;
     QMenu *addToListMenu;
 
 
     PumpController *pController;
+    GlobalObject *globalObj;
     QString contactName;
     QString contactId;
     QString contactUrl;
