@@ -102,7 +102,7 @@ ContactList::ContactList(PumpController *pumpController,
     ASPerson *demoContactPerson = new ASPerson(demoContactData);
     ContactCard *demoContactCard = new ContactCard(this->pController,
                                                    this->globalObj,
-                                                   demoContactPerson);
+                                                   demoContactPerson, this);
     this->contactsLayout->addWidget(demoContactCard);
     this->contactsInList.append(demoContactCard);
 
@@ -143,7 +143,7 @@ void ContactList::setListContents(QString listType,
         ASPerson *person = new ASPerson(contact.toMap());
         ContactCard *contactCard = new ContactCard(this->pController,
                                                    this->globalObj,
-                                                   person);
+                                                   person, this);
 
         contactInfoLineString = person->getName()
                               + "  <"
