@@ -43,13 +43,15 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     topLayout = new QHBoxLayout();
     enterAddressLabel = new QLabel(tr("&Enter address to follow:"));
-    enterAddressLabel->setToolTip("<b></b>" + webfingerHelpMessage); // HTML tags for wordwrap
+    enterAddressLabel->setToolTip("<b></b>"
+                                  + webfingerHelpMessage); // HTML tags for wordwrap
     // Ensure it will get focus first, before addressLineEdit
     enterAddressLabel->setFocusPolicy(Qt::StrongFocus);
 
     addressLineEdit = new QLineEdit();
     addressLineEdit->setPlaceholderText(webfingerHelpMessage);
-    addressLineEdit->setToolTip("<b></b>" + webfingerHelpMessage);  // HTML tags to get wordwrap
+    addressLineEdit->setToolTip("<b></b>"
+                                + webfingerHelpMessage);  // HTML tags to get wordwrap
     connect(addressLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(toggleFollowButton(QString)));
     connect(addressLineEdit, SIGNAL(returnPressed()),
@@ -58,7 +60,8 @@ ContactManager::ContactManager(PumpController *pumpController,
     enterAddressLabel->setBuddy(addressLineEdit);
 
 
-    followButton = new QPushButton(QIcon::fromTheme("list-add-user"),
+    followButton = new QPushButton(QIcon::fromTheme("list-add-user",
+                                                    QIcon(":/images/list-add.png")),
                                    tr("&Follow"));
     followButton->setDisabled(true); // Disabled until an address is typed
     connect(followButton, SIGNAL(clicked()),
@@ -74,7 +77,7 @@ ContactManager::ContactManager(PumpController *pumpController,
     // Widgets for list of 'following' and 'followers'
     this->followingWidget = new ContactList(this->pController,
                                             globalObject,
-                                            "following");
+                                            "following", this);
     connect(pController, SIGNAL(contactFollowed(ASPerson*)),
             followingWidget, SLOT(addSingleContact(ASPerson*)));
     connect(pController, SIGNAL(contactUnfollowed(ASPerson*)),
@@ -86,7 +89,7 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     this->followersWidget = new ContactList(this->pController,
                                             globalObject,
-                                            "followers");
+                                            "followers", this);
 
 
     // Widget for the list of 'person lists'
@@ -98,7 +101,7 @@ ContactManager::ContactManager(PumpController *pumpController,
 
 
     // Options menu
-    optionsMenu = new QMenu("*options-menu*");
+    optionsMenu = new QMenu("*options-menu*", this);
     optionsMenu->addAction(QIcon::fromTheme("view-refresh",
                                             QIcon(":/images/menu-refresh.png")),
                            tr("Reload Followers"),
@@ -110,11 +113,13 @@ ContactManager::ContactManager(PumpController *pumpController,
                            this,
                            SLOT(refreshFollowing()));
     optionsMenu->addSeparator();
-    optionsMenu->addAction(QIcon::fromTheme("document-export"),
+    optionsMenu->addAction(QIcon::fromTheme("document-export",
+                                            QIcon(":/images/button-download.png")),
                            tr("Export Followers"),
                            this,
                            SLOT(exportFollowers()));
-    optionsMenu->addAction(QIcon::fromTheme("document-export"),
+    optionsMenu->addAction(QIcon::fromTheme("document-export",
+                                            QIcon(":/images/button-download.png")),
                            tr("Export Following"),
                            this,
                            SLOT(exportFollowing()));
@@ -134,13 +139,16 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     this->tabWidget = new QTabWidget();
     tabWidget->addTab(followersWidget,
-                      QIcon::fromTheme("meeting-observer"),
+                      QIcon::fromTheme("meeting-observer",
+                                       QIcon(":/images/no-avatar.png")),
                       "*followers*");
     tabWidget->addTab(followingWidget,
-                      QIcon::fromTheme("meeting-participant"),
+                      QIcon::fromTheme("meeting-participant",
+                                       QIcon(":/images/no-avatar.png")),
                       "*following*");
     tabWidget->addTab(listsScrollArea,
-                      QIcon::fromTheme("preferences-contact-list"),
+                      QIcon::fromTheme("preferences-contact-list",
+                                       QIcon(":/images/button-edit.png")),
                       "*lists*");
     tabWidget->setCornerWidget(this->optionsButton);
 
@@ -198,7 +206,8 @@ void ContactManager::exportContactsToFile(QString listType)
                                 + listType;
 
     QString filename = QFileDialog::getSaveFileName(this, dialogTitle,
-                                                    QDir::homePath() + "/" + suggestedFilename,
+                                                    QDir::homePath() + "/"
+                                                    + suggestedFilename,
                                                     "").trimmed();
 
     if (filename.isEmpty()) // If dialog canceled, do nothing
@@ -240,7 +249,7 @@ void ContactManager::setContactListsContents(QString listType,
 
     if (listType == "following")
     {
-        if (totalReceivedCount == 200) // Only for the first batch
+        if (totalReceivedCount <= 200) // Only for the first batch
         {
             this->followingWidget->clearListContents();
             followingCount = 0;
@@ -257,7 +266,7 @@ void ContactManager::setContactListsContents(QString listType,
     }
     else
     {
-        if (totalReceivedCount == 200)
+        if (totalReceivedCount <= 200)
         {
             this->followersWidget->clearListContents();
             followersCount = 0;
@@ -297,11 +306,16 @@ void ContactManager::setListsListContents(QVariantList listsList)
 
 void ContactManager::changeFollowingCount(int difference)
 {
-    this->followingCount += difference;
+    this->followingCount += difference; // FIXME: pumpController should be notified
 
     this->setTabLabels();
 
-    this->tabWidget->setCurrentIndex(1); // Set "Following" tab as active
+    // Set "Following" tab as active, only when the contact manager is not visible
+    // (following someone from an AvatarButton menu)
+    if (!this->isVisible())
+    {
+        this->tabWidget->setCurrentIndex(1);
+    }
 }
 
 
@@ -419,6 +433,8 @@ void ContactManager::followContact()
         this->pController->followContact(address); // this will trigger a reload of the contact list
 
         this->addressLineEdit->clear();
+        // Activate 'Following' tab
+        this->tabWidget->setCurrentIndex(1);
     }
 
 }
