@@ -58,19 +58,23 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     actionTypeComboBox->addItem(QIcon::fromTheme("edit-delete",
                                                  QIcon(":/images/button-delete.png")),
                                 tr("Hide"));
-    actionTypeComboBox->addItem(QIcon::fromTheme("format-fill-color"),
+    actionTypeComboBox->addItem(QIcon::fromTheme("format-fill-color",
+                                                 QIcon(":/images/button-online.png")),
                                 tr("Highlight"));
     actionTypeComboBox->setCurrentIndex(1); // #2 option (highlight) as default
 
     filterTypeComboBox = new QComboBox();
-    filterTypeComboBox->addItem(QIcon::fromTheme("accessories-text-editor"),
+    filterTypeComboBox->addItem(QIcon::fromTheme("accessories-text-editor",
+                                                 QIcon(":/images/button-edit.png")),
                                 tr("Post Contents"));
     filterTypeComboBox->addItem(QIcon::fromTheme("user-identity",
                                                  QIcon(":/images/no-avatar.png")),
                                 tr("Author ID"));
-    filterTypeComboBox->addItem(QIcon::fromTheme("applications-other"),
+    filterTypeComboBox->addItem(QIcon::fromTheme("applications-other",
+                                                 QIcon(":/images/button-configure.png")),
                                 tr("Application"));
-    filterTypeComboBox->addItem(QIcon::fromTheme("accessories-text-editor"),
+    filterTypeComboBox->addItem(QIcon::fromTheme("accessories-text-editor",
+                                                 QIcon(":/images/button-edit.png")),
                                 tr("Activity Description"));
 
     filterWordsLineEdit = new QLineEdit();
