@@ -45,7 +45,8 @@ FontPicker::FontPicker(QString description,
     updateFontSample();
 
 
-    this->button = new QPushButton(QIcon::fromTheme("list-add-font"),
+    this->button = new QPushButton(QIcon::fromTheme("list-add-font",
+                                                    QIcon(":/images/list-add.png")),
                                    tr("Change"));
     connect(button, SIGNAL(clicked()),
             this, SLOT(selectFont()));
