@@ -27,11 +27,9 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
     settings.beginGroup("Configuration");
 
     /////////////////////////////////////////////////////////////////// GENERAL
-    this->syncGeneralSettings(settings.value("minorFeedSnippets", 0).toInt(),
-                              settings.value("snippetsCharLimit", 200).toInt());
 
 
-    /////////////////////////////////////////////////////////////////// FONTS
+    ///////////////////////////////////////////////////////////////////// FONTS
     QFont defaultTitleFont;     // 1 point larger
     defaultTitleFont.setPointSize(defaultTitleFont.pointSize() + 1);
     defaultTitleFont.setBold(true);
@@ -54,7 +52,7 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                           defaultMinorFeedFont).toString());
 
 
-    /////////////////////////////////////////////////////////////////// COLORS
+    //////////////////////////////////////////////////////////////////// COLORS
     this->colorsList.clear();
     colorsList << settings.value("color1", "DISABLED#401020").toString()
                << settings.value("color2", "DISABLED#154060").toString()
@@ -64,6 +62,23 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                << settings.value("color6").toString();
     // no need to call this->syncColorSettings() now...
 
+
+    ///////////////////////////////////////////////////////////////// TIMELINES
+    this->syncTimelinesSettings(settings.value("minorFeedSnippets", 0).toInt(),
+                                settings.value("snippetsCharLimit", 200).toInt());
+
+
+    ///////////////////////////////////////////////////////////////////// POSTS
+    this->syncPostSettings(settings.value("postShowExtraInfo").toBool());
+
+
+    ///////////////////////////////////////////////////////////// NOTIFICATIONS
+
+
+    ////////////////////////////////////////////////////////////////////// TRAY
+
+
+
     settings.endGroup();
 
 
@@ -77,28 +92,15 @@ GlobalObject::~GlobalObject()
 
 
 
-void GlobalObject::syncGeneralSettings(int minorFeedSnippets,
-                                       int snippetsChars)
-{
-    this->minorFeedSnippetsType = minorFeedSnippets;
-    this->snippetsCharLimit = snippetsChars;
 
-    // TODO the rest
-}
-
-int GlobalObject::getMinorFeedSnippetsType()
+// General options
+void GlobalObject::syncGeneralSettings()
 {
-    return this->minorFeedSnippetsType;
-}
-
-int GlobalObject::getSnippetsCharLimit()
-{
-    return this->snippetsCharLimit;
+    // TODO
 }
 
 
-
-
+// Font options
 void GlobalObject::syncFontSettings(QString postTitleFont,
                                     QString postContentsFont,
                                     QString commentsFont,
@@ -133,7 +135,7 @@ QString GlobalObject::getMinorFeedFont()
 }
 
 
-
+// Color options
 void GlobalObject::syncColorSettings(QStringList newColorList)
 {
     this->colorsList = newColorList;
@@ -147,6 +149,57 @@ QStringList GlobalObject::getColorsList()
 }
 
 
+// Timeline options
+void GlobalObject::syncTimelinesSettings(int minorFeedSnippets,
+                                         int snippetsChars)
+{
+    this->minorFeedSnippetsType = minorFeedSnippets;
+    this->snippetsCharLimit = snippetsChars;
+
+    // TODO: more...
+}
+
+int GlobalObject::getMinorFeedSnippetsType()
+{
+    return this->minorFeedSnippetsType;
+}
+
+int GlobalObject::getSnippetsCharLimit()
+{
+    return this->snippetsCharLimit;
+}
+
+
+
+// Post options
+void GlobalObject::syncPostSettings(bool showExtraInfo)
+{
+    this->postShowExtraInfo = showExtraInfo;
+
+    /// TODO: more...
+}
+
+bool GlobalObject::getPostShowExtraInfo()
+{
+    return this->postShowExtraInfo;
+}
+
+
+// Notification options
+void GlobalObject::syncNotificationSettings()
+{
+    // TODO
+}
+
+
+// Tray options
+void GlobalObject::syncTrayOptions()
+{
+    // TODO
+}
+
+
+///////////////////////////////////////////////////////////////////////////////
 
 
 void GlobalObject::createMessageForContact(QString name, QString id)
@@ -157,12 +210,17 @@ void GlobalObject::createMessageForContact(QString name, QString id)
     qDebug() << "GlobalObject; asking for Messaging mode for " << name << id;
 }
 
-void GlobalObject::editPost(QString originalPostId, QString title, QString contents)
+void GlobalObject::editPost(QString originalPostId,
+                            QString type,
+                            QString title,
+                            QString contents)
 {
     // Signal to be caught by Publisher
     emit postEditRequested(originalPostId,
+                           type,
                            title,
                            contents);
 
-    qDebug() << "GlobalObject; asking to edit post: " << originalPostId << title;
+    qDebug() << "GlobalObject; asking to edit post: "
+             << originalPostId << title << type;
 }
