@@ -38,11 +38,10 @@ public:
     ~GlobalObject();
 
 
-    void syncGeneralSettings(int minorFeedSnippets, int snippetsChars);
-    int getMinorFeedSnippetsType();
-    int getSnippetsCharLimit();
-
+    // General options
+    void syncGeneralSettings();
 
+    // Font options
     void syncFontSettings(QString postTitleFont,
                           QString postContentsFont,
                           QString commentsFont,
@@ -53,12 +52,35 @@ public:
     QString getMinorFeedFont();
 
 
+    // Color options
     void syncColorSettings(QStringList newColorList);
     QStringList getColorsList();
 
 
+    // Timeline options
+    void syncTimelinesSettings(int minorFeedSnippets, int snippetsChars);
+    int getMinorFeedSnippetsType();
+    int getSnippetsCharLimit();
+
+
+    // Post options
+    void syncPostSettings(bool showExtraInfo);
+    bool getPostShowExtraInfo();
+
+    // Notification options
+    void syncNotificationSettings();
+
+
+    // Tray options
+    void syncTrayOptions();
+
+
+    ///////////////////////////////////////////////////////////////////////////
+
+
     void createMessageForContact(QString name, QString id);
     void editPost(QString originalPostId,
+                  QString type,
                   QString title,
                   QString contents);
 
@@ -68,6 +90,7 @@ public:
 signals:
     void messagingModeRequested(QString name, QString id);
     void postEditRequested(QString originalPostId,
+                           QString type,
                            QString title,
                            QString contents);
 
@@ -77,15 +100,35 @@ public slots:
 
 
 private:
-    int minorFeedSnippetsType;
-    int snippetsCharLimit;
+    // General options
 
+
+    // Font options
     QString postTitleFontInfo;
     QString postContentsFontInfo;
     QString commentsFontInfo;
     QString minorFeedFontInfo;
 
+
+    // Color options
     QStringList colorsList;
+
+
+    // Timeline options
+    int minorFeedSnippetsType;
+    int snippetsCharLimit;
+
+
+    // Post options
+    bool postShowExtraInfo;
+
+
+    // Notification options
+
+
+    // Tray options
+
+
 };
 
 #endif // GLOBALOBJECT_H
