@@ -27,7 +27,7 @@ GroupsManager::GroupsManager(PumpController *pumpController,
 
     this->setWindowTitle("GROUPS MANAGER"  " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("user-group-properties"));
-    this->setWindowFlags(Qt::Window);
+    this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
     this->setMinimumSize(400, 400);
 
@@ -96,6 +96,12 @@ GroupsManager::~GroupsManager()
 
 void GroupsManager::createGroup()
 {
+    if (newGroupNameLineEdit->text().trimmed().isEmpty())
+    {
+        QMessageBox::warning(this, "ERROR",
+                             "Groups require a name.");
+        return;
+    }
     qDebug() << "Creating group...";
 
     this->pController->createGroup(this->newGroupNameLineEdit->text().trimmed(),
@@ -116,6 +122,13 @@ void GroupsManager::deleteGroup()
 
 void GroupsManager::joinGroup()
 {
+    if (joinLeaveGroupLineEdit->text().trimmed().isEmpty())
+    {
+        QMessageBox::warning(this, "ERROR",
+                             "ID of group to join is empty.");
+        return;
+    }
+
     qDebug() << "Joining group...";
     this->pController->joinGroup(this->joinLeaveGroupLineEdit->text().trimmed());
 
@@ -125,6 +138,12 @@ void GroupsManager::joinGroup()
 
 void GroupsManager::leaveGroup()
 {
+    if (joinLeaveGroupLineEdit->text().trimmed().isEmpty())
+    {
+        QMessageBox::warning(this, "ERROR",
+                             "ID of group to leave is empty.");
+        return;
+    }
     qDebug() << "Leaving group...";
     this->pController->leaveGroup(this->joinLeaveGroupLineEdit->text().trimmed());
 
