@@ -22,6 +22,8 @@
 #define HCLABEL_H
 
 #include <QLabel>
+#include <QMouseEvent>
+#include <QTimer>
 
 #include <QDebug>
 
@@ -37,11 +39,31 @@ public:
 
     void setHighlighted(bool highlighted);
 
+    void setBaseText(QString text);
+    void setExtendedText(QString text);
+
+    void setExpanded(bool isExpanded);
+
+
 signals:
     void clicked();
 
-public slots:
 
+public slots:
+    void toggleContent();
+
+
+protected:
+    virtual void mousePressEvent(QMouseEvent *event);
+
+
+private:
+    QString baseText;
+    QString extendedText;
+
+    bool expanded;
+
+    QTimer *toggleTimer;
 };
 
 #endif // HCLABEL_H
