@@ -88,7 +88,12 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append(tr("Keep in mind that there are a lot of places in Dianara "
                        "where you can get more information by hovering over some "
                        "text or button with your mouse, and waiting for the "
-                       "tooltip to appear."));
+                       "tooltip to appear.")
+                    + "<br><br>");
+    helpText.append(tr("If you're new to Pump.io, take a look at this guide:")
+                    + " <a href=\"https://github.com/e14n/pump.io/wiki/User-Guide\">"
+                    + tr("Pump.io User Guide")
+                    + "</a>");
 
 
     helpText.append("<br><hr>");
@@ -111,7 +116,7 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
 
     helpText.append("<a id=timelines><h1>" + sectionTimelines + "</h1></a>");
 
-    helpText.append(tr("There are five timelines:")
+    helpText.append(tr("There are seven timelines:")
                     + "<ul>"
                     + "<li>"
                     + tr("The main timeline, where you'll see all the stuff "
@@ -135,6 +140,11 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                        "done by everyone you follow, such as comment actions, "
                        "liking posts or following people.")
                     + "<br>"
+                    + tr("The sixth and seventh timelines are also minor "
+                         "timelines, similar to the Meanwhile, but containing "
+                         "only activities directly addressed to you (Mentions) "
+                         "and activities done by you (Actions).")
+                    + "<br><br>"
                     + tr("These activities might have a '+' button in them. "
                          "Press it to open the post they're referencing. "
                          "Also, as in many other places, you can hover with "
@@ -165,7 +175,7 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                        "require text to be selected before they are used.")
                     + "<br><br>");
     helpText.append(tr("You can select who will see your post by using the "
-                       "To and CC buttons.")
+                       "To and Cc buttons.")
                     + " "
                     + tr("If you add a specific person to the 'To' list, they "
                          "will receive your message in their direct messages tab.")
@@ -197,7 +207,7 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append(tr("You can find a list with some Pump.io users "
                        "and other information here:")
                     + " <a href=\"https://static.jpope.org/users.html\">"
-                      "https://static.jpope.org/users.html"
+                      "static.jpope.org/users.html"
                       "</a>");
 
 
@@ -222,6 +232,9 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                     + tr("Control+G to go to any page in the timeline "
                          "directly.") + "</li>"
                     + "<li>"
+                    + tr("Control+1/2/3 to switch between the minor "
+                         "feeds.") + "</li>"
+                    + "<li>"
                     + tr("Control+Enter to post, when you're done composing "
                          "a note or a comment. If the note is empty, you can "
                          "cancel it by pressing ESC.") + "</li>"
