@@ -54,7 +54,8 @@ ImageViewer::ImageViewer(QString fileURI,
 
 
     this->setWindowTitle(tr("Image") + ": " + title + " - Dianara");
-    this->setWindowIcon(QIcon::fromTheme("folder-image"));
+    this->setWindowIcon(QIcon::fromTheme("folder-image",
+                                         QIcon(":/images/attached-image.png")));
 
     imageLabel = new QLabel();
     imageLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
@@ -81,7 +82,8 @@ ImageViewer::ImageViewer(QString fileURI,
 
         imageLabel->setMovie(movie);
 
-        restartButton = new QPushButton(QIcon::fromTheme("media-playback-start"),
+        restartButton = new QPushButton(QIcon::fromTheme("media-playback-start",
+                                                         QIcon(":/images/menu-refresh.png")),
                                         tr("&Restart Animation"));
         connect(restartButton, SIGNAL(clicked()),
                 this, SLOT(restartAnimation()));
@@ -155,7 +157,7 @@ void ImageViewer::createContextMenu()
             this, SLOT(close()));
 
 
-    this->contextMenu = new QMenu("imageViewerMenu");
+    this->contextMenu = new QMenu("imageViewerMenu", this);
     contextMenu->addAction(saveAction);
     contextMenu->addAction(closeAction);
 
