@@ -66,7 +66,6 @@ protected:
     virtual void closeEvent(QCloseEvent *event);
     virtual void hideEvent(QHideEvent *event);
     virtual void resizeEvent(QResizeEvent *event);
-    virtual void keyPressEvent(QKeyEvent *event);
     virtual void contextMenuEvent(QContextMenuEvent *event);
 
 
@@ -81,6 +80,8 @@ private:
     QPushButton *closeButton;
 
     QMenu *contextMenu;
+    QAction *saveAction;
+    QAction *closeAction;
 
     QPixmap originalPixmap;
     QString originalFileURI;
