@@ -49,7 +49,8 @@ LogViewer::LogViewer(QWidget *parent) : QWidget(parent)
     logTextBrowser->setOpenExternalLinks(true);
 
 
-    clearButton = new QPushButton(QIcon::fromTheme("edit-clear-list"),
+    clearButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
+                                                   QIcon(":/images/button-delete.png")),
                                   tr("Clear &Log"));
     connect(clearButton, SIGNAL(clicked()),
             logTextBrowser, SLOT(clear()));
@@ -97,6 +98,17 @@ void LogViewer::hideEvent(QHideEvent *event)
 }
 
 
+/*
+ * Scroll log to bottom when showing
+ *
+ */
+void LogViewer::showEvent(QShowEvent *event)
+{
+    this->logTextBrowser->moveCursor(QTextCursor::End);
+    event->accept();
+}
+
+
 /****************************************************************************/
 /********************************* SLOTS ************************************/
 /****************************************************************************/
