@@ -47,6 +47,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
         qDebug() << ">> No system iconset (or hicolor) configured; trying to use Oxygen";
         QIcon::setThemeName("oxygen"); // VERY TMP; FIXME
     }
+#if 0 // 1 to test the fallback icons
+    QIcon::setThemeSearchPaths(QStringList() << "./");
+#endif
 
     // Network control
     pumpController = new PumpController(this);
@@ -89,6 +92,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     fullNameLabel = new QLabel("[-------------]");
     fullNameLabel->setWordWrap(true);
+    fullNameLabel->setSizePolicy(QSizePolicy::Ignored,
+                                 QSizePolicy::Minimum);
 
     QFont userDetailsFont;
     userDetailsFont.setBold(true);
@@ -97,15 +102,17 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     userIdLabel = new QLabel();
     userIdLabel->setWordWrap(true);
-    userIdLabel->setFont(userDetailsFont);
     userIdLabel->setSizePolicy(QSizePolicy::Ignored,
                                QSizePolicy::Minimum);
+    userIdLabel->setFont(userDetailsFont);
 
     userDetailsFont.setBold(false);
     userDetailsFont.setItalic(false);
 
     userHometownLabel = new QLabel();
     userHometownLabel->setWordWrap(true);
+    userHometownLabel->setSizePolicy(QSizePolicy::Ignored,
+                                     QSizePolicy::Minimum);
     userHometownLabel->setFont(userDetailsFont);
 
 
@@ -120,27 +127,87 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     leftTopLayout->addLayout(userInfoLayout,   1);
 
 
-    leftPanel = new QToolBox(); // For now, only one "section"...
+    leftPanel = new QToolBox(); // Will hold the minor feeds
+    leftPanel->setContentsMargins(0, 0, 0, 0);
 
-    meanwhileFeed = new MinorFeed(pumpController,
+    //////// Meanwhile feed: inbox/minor
+    meanwhileFeed = new MinorFeed(PumpController::MinorFeedMainRequest,
+                                  pumpController,
                                   globalObject,
-                                  filterChecker);
+                                  filterChecker, this);
     connect(meanwhileFeed, SIGNAL(newItemsCountChanged(int,int)),
             this, SLOT(setMinorFeedTitle(int,int)));
     connect(meanwhileFeed, SIGNAL(newItemsReceived(int,int)),
             this, SLOT(notifyMinorFeedUpdate(int,int)));
     leftPanel->addItem(meanwhileFeed,
-                       QIcon::fromTheme("clock"),
+                       QIcon::fromTheme("clock",
+                                        QIcon(":/images/feed-clock.png")),
                        "*meanwhile*");
     this->setMinorFeedTitle(0, 0); // Set initial title (0 new, 0 HL)
+    leftPanel->setItemToolTip(0,
+                              "<b></b>"
+                              + tr("Minor activities done by everyone, such "
+                                   "as replying to posts"));
+
+
+    //////// Mentions feed: inbox/direct/minor
+    mentionsFeed = new MinorFeed(PumpController::MinorFeedDirectRequest,
+                                 pumpController,
+                                 globalObject,
+                                 filterChecker, this);
+    connect(mentionsFeed, SIGNAL(newItemsCountChanged(int,int)),
+            this, SLOT(setMentionsFeedTitle(int,int)));
+    connect(mentionsFeed, SIGNAL(newItemsReceived(int,int)),
+            this, SLOT(notifyMentionsFeedUpdate(int,int)));
+    leftPanel->addItem(mentionsFeed,
+                       QIcon::fromTheme("mail-folder-inbox",
+                                        QIcon(":/images/feed-inbox.png")),
+                       "*mentions*");
+    this->setMentionsFeedTitle(0, 0); // Set initial title, with 0 new
+    leftPanel->setItemToolTip(1, "<b></b>"
+                                 + tr("Minor activities addressed to you"));
+
+
+    //////// Actions feed: feed/minor
+    actionsFeed = new MinorFeed(PumpController::MinorFeedActivityRequest,
+                                pumpController,
+                                globalObject,
+                                filterChecker, this);
+    leftPanel->addItem(actionsFeed,
+                       QIcon::fromTheme("mail-folder-outbox",
+                                        QIcon(":/images/feed-outbox.png")),
+                       tr("Actions"));
+    leftPanel->setItemToolTip(2, "<b></b>"
+                                 + tr("Minor activities done by you"));
+
 
 
     leftSideWidget = new QWidget();
     leftLayout = new QVBoxLayout();
     leftLayout->setContentsMargins(0, 0, 0, 0);
-    leftLayout->addLayout(leftTopLayout);       // Avatar + user info
-    leftLayout->addSpacing(2);
-    leftLayout->addWidget(leftPanel);           // Meanwhile feed
+    leftLayout->addLayout(leftTopLayout);    // Avatar + user info
+    leftLayout->addSpacing(1);
+    leftLayout->addWidget(leftPanel);        // Meanwhile and other minor feeds
+
+    // Shortcuts to change between the different minor feeds
+    this->showMeanwhileFeed = new QAction(this);
+    showMeanwhileFeed->setShortcut(QKeySequence("Ctrl+1"));
+    connect(showMeanwhileFeed, SIGNAL(triggered()),
+            this, SLOT(toggleMeanwhileFeed()));
+    this->addAction(showMeanwhileFeed);
+
+    this->showMentionsFeed = new QAction(this);
+    showMentionsFeed->setShortcut(QKeySequence("Ctrl+2"));
+    connect(showMentionsFeed, SIGNAL(triggered()),
+            this, SLOT(toggleMentionsFeed()));
+    this->addAction(showMentionsFeed);
+
+    this->showActionsFeed = new QAction(this);
+    showActionsFeed->setShortcut(QKeySequence("Ctrl+3"));
+    connect(showActionsFeed, SIGNAL(triggered()),
+            this, SLOT(toggleActionsFeed()));
+    this->addAction(showActionsFeed);
+
 
 ////////////////////////////////////////////////////////////////////////////////
 /////////////////////////////////////////////////// TMP GROUP MANAGER STUFF
@@ -148,7 +215,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
-#if 0
+#ifdef GROUPSUPPORT
     GroupsManager *TMPGROUPSMANAGER = new GroupsManager(this->pumpController,
                                                         this);
 
@@ -302,25 +369,33 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     tabWidget = new QTabWidget();
     tabWidget->addTab(mainTimelineScrollArea,
-                      QIcon::fromTheme("view-list-details"),
-                      "MAIN TIMELINE TAB");
+                      QIcon::fromTheme("view-list-details",
+                                       QIcon(":/images/feed-inbox.png")),
+                      "*MAIN TIMELINE TAB*");
     this->setTimelineTabTitle(TimeLine::TimelineTypeMain, 0, 0, 0);
     tabWidget->addTab(directTimelineScrollArea,
-                      QIcon::fromTheme("mail-message"),
-                      "MESSAGES TAB");
+                      QIcon::fromTheme("mail-message",
+                                       QIcon(":/images/feed-inbox.png")),
+                      "*MESSAGES TAB*");
     this->setTimelineTabTitle(TimeLine::TimelineTypeDirect, 0, 0, 0);
     tabWidget->addTab(activityTimelineScrollArea,
-                      QIcon::fromTheme("user-home"),
-                      "ACTIVITY TAB");
+                      QIcon::fromTheme("user-home",
+                                       QIcon(":/images/feed-outbox.png")),
+                      "*ACTIVITY TAB*");
     this->setTimelineTabTitle(TimeLine::TimelineTypeActivity, 0, 0, 0);
     tabWidget->addTab(favoritesTimelineScrollArea,
-                      QIcon::fromTheme("folder-favorites"),
-                      "FAVORITES TAB");
+                      QIcon::fromTheme("folder-favorites",
+                                       QIcon(":/images/button-like.png")),
+                      "*FAVORITES TAB*");
     this->setTimelineTabTitle(TimeLine::TimelineTypeFavorites, 0, 0, 0);
     tabWidget->addTab(contactManager,
-                      QIcon::fromTheme("system-users"),
+                      QIcon::fromTheme("system-users",
+                                       QIcon(":/images/no-avatar.png")),
                       tr("&Contacts"));
-    tabWidget->setTabToolTip(4, tr("The people you follow, and the ones who follow you"));
+    tabWidget->setTabToolTip(4,
+                             "<b></b>"  // HTMLized for wordwrap
+                             + tr("The people you follow, the ones who "
+                                  "follow you, and your person lists"));
     connect(tabWidget, SIGNAL(currentChanged(int)),
             this, SLOT(setTitleAndTrayInfo(int)));
 
@@ -338,7 +413,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
     // FreeDesktop.org notifications handler
-    fdNotifier = new FDNotifications();
+    fdNotifier = new FDNotifications(this);
     connect(fdNotifier, SIGNAL(showFallbackNotification(QString,QString)),
             this, SLOT(showTrayFallbackMessage(QString,QString)));
 
@@ -480,9 +555,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     // TODO***
 
 
-    // After receiving the minor feed ("Meanwhile"), update it
-    connect(pumpController, SIGNAL(minorFeedReceived(QVariantList,QString,QString)),
+    // After receiving the main minor feed ("Meanwhile"), update it
+    connect(pumpController, SIGNAL(minorFeedMainReceived(QVariantList,QString,QString)),
             meanwhileFeed, SLOT(setFeedContents(QVariantList,QString,QString)));
+    // Also for Direct ("Mentions") and Feed/Minor ("Activities")
+    connect(pumpController, SIGNAL(minorFeedDirectReceived(QVariantList,QString,QString)),
+            mentionsFeed, SLOT(setFeedContents(QVariantList,QString,QString)));
+    connect(pumpController, SIGNAL(minorFeedActivityReceived(QVariantList,QString,QString)),
+            actionsFeed, SLOT(setFeedContents(QVariantList,QString,QString)));
 
 
     // Show notifications for events sent from pumpController
@@ -523,7 +603,10 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     settings.endGroup();
 
 
+    initializationComplete = false;
+
     logViewer->addToLog(tr("Dianara started."));
+    logViewer->addToLog(QString("Qt v%1.").arg(qVersion()));
 
     // If User ID is defined, set PumpController in motion
     if (!userID.isEmpty())
@@ -652,7 +735,7 @@ void MainWindow::prepareDataDirectory()
  */
 void MainWindow::createMenus()
 {
-    sessionMenu = new QMenu(tr("&Session"));
+    sessionMenu = new QMenu(tr("&Session"), this);
 
     sessionUpdateMainTimeline = new QAction(QIcon::fromTheme("view-refresh",
                                                              QIcon(":/images/menu-refresh.png")),
@@ -695,28 +778,43 @@ void MainWindow::createMenus()
             favoritesTimeline, SLOT(goToFirstPage()));
     sessionMenu->addAction(sessionUpdateFavoritesTimeline);
 
+    sessionMenu->addSeparator(); // ------
 
-    sessionUpdateMinorFeed = new QAction(QIcon::fromTheme("view-refresh",
+    sessionUpdateMinorFeedMain = new QAction(QIcon::fromTheme("view-refresh",
                                                           QIcon(":/images/menu-refresh.png")),
-                                         tr("Update Minor &Feed"),
-                                         this);
-    sessionUpdateMinorFeed->setShortcut(QKeySequence(Qt::Key_F10));
-    sessionUpdateMinorFeed->setDisabled(true);
-    connect(sessionUpdateMinorFeed, SIGNAL(triggered()),
+                                             tr("Update Minor &Feed"),
+                                             this);
+    sessionUpdateMinorFeedMain->setShortcut(QKeySequence(Qt::Key_F2));
+    sessionUpdateMinorFeedMain->setDisabled(true);
+    connect(sessionUpdateMinorFeedMain, SIGNAL(triggered()),
             meanwhileFeed, SLOT(updateFeed()));
-    sessionMenu->addAction(sessionUpdateMinorFeed);
+    sessionMenu->addAction(sessionUpdateMinorFeedMain);
 
 
-    sessionUpdateAllTimelines = new QAction(QIcon::fromTheme("view-refresh",
-                                                             QIcon(":/images/menu-refresh.png")),
-                                         tr("Update All Timelines"),
-                                         this);
-    sessionUpdateAllTimelines->setDisabled(true);
-    connect(sessionUpdateAllTimelines, SIGNAL(triggered()),
-            this, SLOT(updateAllTimelines()));
-    sessionMenu->addAction(sessionUpdateAllTimelines);
+    sessionUpdateMinorFeedDirect = new QAction(QIcon::fromTheme("view-refresh",
+                                                                QIcon(":/images/menu-refresh.png")),
+                                               tr("Update Mentions"),
+                                               this);
+    sessionUpdateMinorFeedDirect->setShortcut(QKeySequence(Qt::Key_F3));
+    sessionUpdateMinorFeedDirect->setDisabled(true);
+    connect(sessionUpdateMinorFeedDirect, SIGNAL(triggered()),
+            mentionsFeed, SLOT(updateFeed()));
+    sessionMenu->addAction(sessionUpdateMinorFeedDirect);
 
-    sessionAutoUpdates = new QAction(QIcon::fromTheme("clock"),
+    sessionUpdateMinorFeedActivity = new QAction(QIcon::fromTheme("view-refresh",
+                                                                  QIcon(":/images/menu-refresh.png")),
+                                                 tr("Update Actions"),
+                                                 this);
+    sessionUpdateMinorFeedActivity->setShortcut(QKeySequence(Qt::Key_F4));
+    sessionUpdateMinorFeedActivity->setDisabled(true);
+    connect(sessionUpdateMinorFeedActivity, SIGNAL(triggered()),
+            actionsFeed, SLOT(updateFeed()));
+    sessionMenu->addAction(sessionUpdateMinorFeedActivity);
+
+    //////////////////////////////////////////////////////////
+
+    sessionAutoUpdates = new QAction(QIcon::fromTheme("clock",
+                                                      QIcon(":/images/feed-clock.png")),
                                      tr("Auto-update &Timelines"),
                                      this);
     sessionAutoUpdates->setCheckable(true);
@@ -752,7 +850,8 @@ void MainWindow::createMenus()
 
     sessionMenu->addSeparator();
 
-    sessionQuit = new QAction(QIcon::fromTheme("application-exit"),
+    sessionQuit = new QAction(QIcon::fromTheme("application-exit",
+                                               QIcon(":/images/button-delete.png")),
                               tr("&Quit"), this);
     sessionQuit->setShortcut(QKeySequence("Ctrl+Q"));
     connect(sessionQuit, SIGNAL(triggered()),
@@ -762,7 +861,7 @@ void MainWindow::createMenus()
     this->menuBar()->addMenu(sessionMenu);
 
 
-    viewMenu = new QMenu(tr("&View"));
+    viewMenu = new QMenu(tr("&View"), this);
 
     viewSidePanel = new QAction(QIcon::fromTheme("view-sidetree"),
                                 tr("Side &Panel"), this);
@@ -820,7 +919,7 @@ void MainWindow::createMenus()
 
 
 
-    settingsMenu = new QMenu(tr("S&ettings"));
+    settingsMenu = new QMenu(tr("S&ettings"), this);
 
     settingsEditProfile = new QAction(QIcon::fromTheme("user-properties",
                                                        QIcon(":/images/no-avatar.png")),
@@ -830,7 +929,8 @@ void MainWindow::createMenus()
             profileEditor, SLOT(show()));
     settingsMenu->addAction(settingsEditProfile);
 
-    settingsAccount = new QAction(QIcon::fromTheme("dialog-password"),
+    settingsAccount = new QAction(QIcon::fromTheme("dialog-password",
+                                                   QIcon(":/images/button-password.png")),
                                   tr("&Account"), this);
     connect(settingsAccount, SIGNAL(triggered()),
             accountDialog, SLOT(show()));
@@ -858,7 +958,7 @@ void MainWindow::createMenus()
 
 
 
-    helpMenu = new QMenu(tr("&Help"));
+    helpMenu = new QMenu(tr("&Help"), this);
 
     helpBasicHelp = new QAction(QIcon::fromTheme("help-browser"),
                                 tr("Basic &Help"), this);
@@ -867,19 +967,33 @@ void MainWindow::createMenus()
             helpWidget, SLOT(show()));
     helpMenu->addAction(helpBasicHelp);
 
-    helpMenu->addSeparator();
 
-    helpVisitWebsite = new QAction(QIcon::fromTheme("internet-web-browser"),
-                            tr("Visit &Website"), this);
+    helpMenu->addSeparator(); // ---
+
+
+    helpVisitWebsite = new QAction(QIcon::fromTheme("internet-web-browser",
+                                                    QIcon(":/icon/64x64/dianara.png")),
+                                   tr("Visit &Website"), this);
     connect(helpVisitWebsite, SIGNAL(triggered()),
             this, SLOT(visitWebSite()));
     helpMenu->addAction(helpVisitWebsite);
 
-    helpVisitPumpFAQ = new QAction(QIcon::fromTheme("internet-web-browser"),
-                                  tr("&Frequently Asked Questions about Pump.io"), this);
-    connect(helpVisitPumpFAQ, SIGNAL(triggered()),
-            this, SLOT(visitFAQ()));
-    helpMenu->addAction(helpVisitPumpFAQ);
+    helpVisitBugTracker = new QAction(QIcon::fromTheme("internet-web-browser",
+                                                       QIcon(":/icon/64x64/dianara.png")),
+                                      tr("Report a &Bug"), this);
+    connect(helpVisitBugTracker, SIGNAL(triggered()),
+            this, SLOT(visitBugTracker()));
+    helpMenu->addAction(helpVisitBugTracker);
+
+
+    helpMenu->addSeparator(); // ---
+
+
+    helpVisitPumpGuide = new QAction(QIcon::fromTheme("internet-web-browser"),
+                                     tr("Pump.io User &Guide"), this);
+    connect(helpVisitPumpGuide, SIGNAL(triggered()),
+            this, SLOT(visitPumpGuide()));
+    helpMenu->addAction(helpVisitPumpGuide);
 
     helpVisitPumpTips = new QAction(QIcon::fromTheme("internet-web-browser"),
                                     tr("Some Pump.io &Tips"), this);
@@ -894,7 +1008,8 @@ void MainWindow::createMenus()
     helpMenu->addAction(helpVisitPumpUserList);
 
 
-    helpMenu->addSeparator();
+    helpMenu->addSeparator(); // ---
+
 
     helpAbout = new QAction(QIcon(":/icon/64x64/dianara.png"),
                             tr("About &Dianara"), this);
@@ -916,13 +1031,13 @@ void MainWindow::createMenus()
     connect(trayShowWindowAction, SIGNAL(triggered()),
             this, SLOT(toggleMainWindow()));
 
-    trayContextMenu = new QMenu("Tray Context Menu");
+    trayContextMenu = new QMenu("Tray Context Menu", this);
     trayContextMenu->setSeparatorsCollapsible(false);
     trayContextMenu->addAction(trayTitleSeparatorAction); // Acts as title
     trayContextMenu->addAction(trayShowWindowAction);
     trayContextMenu->addSeparator();
     trayContextMenu->addAction(sessionUpdateMainTimeline);
-    trayContextMenu->addAction(sessionUpdateMinorFeed);
+    trayContextMenu->addAction(sessionUpdateMinorFeedMain);
     trayContextMenu->addAction(sessionAutoUpdates);
     trayContextMenu->addSeparator();
     trayContextMenu->addAction(sessionMarkAllAsRead);
@@ -952,7 +1067,7 @@ void MainWindow::createToolbar()
     mainToolBar->setMovable(false);
 
     mainToolBar->addAction(this->sessionUpdateMainTimeline);
-    mainToolBar->addAction(this->sessionUpdateMinorFeed);
+    mainToolBar->addAction(this->sessionUpdateMinorFeedMain);
     mainToolBar->addAction(this->sessionMarkAllAsRead);
     mainToolBar->addSeparator();
     this->settingsFilters->setPriority(QAction::LowPriority); // Don't show text in besides-icon mode
@@ -1240,9 +1355,6 @@ void MainWindow::updateUserID(QString newUserID)
     // update window title and tray icon tooltip
     this->setTitleAndTrayInfo(tabWidget->currentIndex());
 
-    this->pumpController->setUserCredentials(userID);
-    this->fdNotifier->setCurrentUserId(userID);
-
     // Remove current user's name, id and avatar
     this->fullNameLabel->setText("--");
     this->userIdLabel->setText("_@_");
@@ -1253,6 +1365,10 @@ void MainWindow::updateUserID(QString newUserID)
                                             Qt::KeepAspectRatio,
                                             Qt::SmoothTransformation)));
 
+    // Restart initialization process
+    this->initializationComplete = false;
+    this->pumpController->setUserCredentials(userID);
+    this->fdNotifier->setCurrentUserId(userID);
 
     qDebug() << "UserID updated from AccountDialog:" << userID;
 }
@@ -1269,12 +1385,25 @@ void MainWindow::updateConfigSettings()
     settings.beginGroup("Configuration");
 
     this->updateInterval = settings.value("updateInterval", 5).toInt();
+    if (updateInterval < 2 || updateInterval > 99)
+    {
+        updateInterval = 5; // TMP validation of stored setting - FIXME
+        // Should be loaded and validated by GlobalObject
+    }
     this->updateTimer->setInterval(updateInterval * 1000 * 60);  // min > msec
 
     this->postsPerPageMain = settings.value("postsPerPageMain", 20).toInt();
+    if (postsPerPageMain < 5 || postsPerPageMain > 50)
+    {
+        postsPerPageMain = 20; // TMP validation of stored setting - FIXME
+    }
     this->pumpController->setPostsPerPageMain(this->postsPerPageMain);
 
     this->postsPerPageOther = settings.value("postsPerPageOther", 5).toInt();
+    if (postsPerPageOther < 1 || postsPerPageOther > 30)
+    {
+        postsPerPageOther = 5; // TMP validation of stored setting - FIXME
+    }
     this->pumpController->setPostsPerPageOther(this->postsPerPageOther);
 
     this->tabsPosition = settings.value("tabsPosition", QTabWidget::North).toInt();
@@ -1349,8 +1478,10 @@ void MainWindow::toggleWidgetsByAuthorization(bool authorized)
     this->sessionUpdateDirectTimeline->setEnabled(authorized);
     this->sessionUpdateActivityTimeline->setEnabled(authorized);
     this->sessionUpdateFavoritesTimeline->setEnabled(authorized);
-    this->sessionUpdateMinorFeed->setEnabled(authorized);
-    this->sessionUpdateAllTimelines->setEnabled(authorized);
+
+    this->sessionUpdateMinorFeedMain->setEnabled(authorized);
+    this->sessionUpdateMinorFeedDirect->setEnabled(authorized);
+    this->sessionUpdateMinorFeedActivity->setEnabled(authorized);
 
     if (authorized)
     {
@@ -1365,6 +1496,7 @@ void MainWindow::toggleWidgetsByAuthorization(bool authorized)
 
 void MainWindow::onInitializationComplete()
 {
+    this->initializationComplete = true;
     this->sessionAutoUpdates->setEnabled(true);
 
     if (this->sessionAutoUpdates->isChecked())
@@ -1555,6 +1687,8 @@ void MainWindow::updateAllTimelines()
     favoritesTimeline->goToFirstPage();
 
     meanwhileFeed->updateFeed();
+    mentionsFeed->updateFeed();
+    actionsFeed->updateFeed();
 
     qDebug() << "Updated all timelines by menu";
 }
@@ -1736,7 +1870,8 @@ void MainWindow::setTimelineTabTitle(int timelineType,
     }
 
 
-    QString totalItemsString = "\n\n" + tr("Total posts: %1").arg(totalItemsCount);
+    QString totalItemsString = "\n\n"
+                               + tr("Total posts: %1").arg(totalItemsCount);
 
     switch (timelineType)
     {
@@ -1866,6 +2001,21 @@ void MainWindow::setMinorFeedTitle(int newItemsCount,
 }
 
 
+void MainWindow::setMentionsFeedTitle(int newItemsCount,
+                                      int newHighlightedItemsCount)
+{
+    Q_UNUSED(newHighlightedItemsCount)
+
+    QString title = tr("Mentions");
+    if (newItemsCount > 0)
+    {
+        title.append(QString(" (%1)").arg(newItemsCount));
+    }
+
+    this->leftPanel->setItemText(1, title);
+}
+
+
 
 
 void MainWindow::notifyMinorFeedUpdate(int newItemsCount, int highlightedCount)
@@ -1922,9 +2072,20 @@ void MainWindow::notifyMinorFeedUpdate(int newItemsCount, int highlightedCount)
                 fdNotifier->showMessage(mwUpdatedAt + "\n\n"
                                         + newItemsString);
             }
-
         }
 
+        // Some highlighted could mean some new mentions, so update that feed
+        if (highlightedCount > 0 || newItemsCount >= 50) // Also if more than max new activities
+        {
+            if (initializationComplete) // But not the first time
+            {
+                // Store statusBarMessage, and restore after the Mentions feed is updated
+                this->previousStatusMessageForMinorFeed = statusBarMessage;
+                // This is temporary; FIXME
+
+                this->mentionsFeed->updateFeed();
+            }
+        }
 
         this->setStatusBarMessage(statusBarMessage);
         this->logViewer->addToLog(statusBarMessage);
@@ -1937,6 +2098,23 @@ void MainWindow::notifyMinorFeedUpdate(int newItemsCount, int highlightedCount)
 }
 
 
+/*
+ * This is temporarily only used to restore the previous content of the status
+ * bar after an automated reload of the Mentions feed, after receiving the
+ * Meanwhile feed with >50 activities or some hightlighted items
+ *
+ */
+void MainWindow::notifyMentionsFeedUpdate(int newItemsCount, int highlightedCount)
+{
+    qDebug() << "Mentions feed updated: " << newItemsCount << highlightedCount;
+    if (!this->previousStatusMessageForMinorFeed.isEmpty())
+    {
+        this->setStatusBarMessage(previousStatusMessageForMinorFeed);
+        previousStatusMessageForMinorFeed.clear();
+    }
+}
+
+
 
 
 /*
@@ -1993,12 +2171,13 @@ void MainWindow::storeImage(QByteArray imageData, QUrl imageUrl)
 
 
 /*
- * Update status bar message, from pumpController's signals
+ * Update status bar message, from PumpController's signals
  *
  */
 void MainWindow::setStatusBarMessage(QString message)
 {
-    this->oldStatusBarMessage = "[" + QTime::currentTime().toString() + "] " + message;
+    this->oldStatusBarMessage = "[" + QTime::currentTime().toString() + "] "
+                                + message;
     this->statusBar()->showMessage(oldStatusBarMessage, 0);
 }
 
@@ -2036,11 +2215,14 @@ void MainWindow::markAllAsRead()
 {
     mainTimeline->markPostsAsRead();
     directTimeline->markPostsAsRead();
-    activityTimeline->markPostsAsRead();
+    // activityTimeline doesn't need this; they're never "unread"
     favoritesTimeline->markPostsAsRead();
 
     meanwhileFeed->markAllAsRead();
     this->setMinorFeedTitle(0, 0);
+
+    mentionsFeed->markAllAsRead();
+    // activitiesFeed doesn't need this, either
 }
 
 
@@ -2051,11 +2233,14 @@ void MainWindow::markAllAsRead()
  */
 void MainWindow::refreshAllTimestamps()
 {
-    this->meanwhileFeed->updateFuzzyTimestamps();
     this->mainTimeline->updateFuzzyTimestamps();
     this->directTimeline->updateFuzzyTimestamps();
     this->activityTimeline->updateFuzzyTimestamps();
     this->favoritesTimeline->updateFuzzyTimestamps();
+
+    this->meanwhileFeed->updateFuzzyTimestamps();
+    this->mentionsFeed->updateFuzzyTimestamps();
+    this->actionsFeed->updateFuzzyTimestamps();
 }
 
 
@@ -2184,6 +2369,24 @@ void MainWindow::toggleFullscreen(bool enabled)
 }
 
 
+void MainWindow::toggleMeanwhileFeed()
+{
+    this->leftPanel->setCurrentIndex(0);
+    this->meanwhileFeed->setFocus();
+}
+
+void MainWindow::toggleMentionsFeed()
+{
+    this->leftPanel->setCurrentIndex(1);
+    this->mentionsFeed->setFocus();
+}
+
+void MainWindow::toggleActionsFeed()
+{
+    this->leftPanel->setCurrentIndex(2);
+    this->actionsFeed->setFocus();
+}
+
 
 
 
@@ -2197,15 +2400,21 @@ void MainWindow::visitWebSite()
     QDesktopServices::openUrl(QUrl("http://jancoding.wordpress.com/dianara"));
 }
 
+void MainWindow::visitBugTracker()
+{
+    qDebug() << "Opening bugtracker in browser";
+    QDesktopServices::openUrl(QUrl("https://gitorious.org/projects/dianara/issues"));
+}
+
 /*
- * Open pump.io's FAQ in web browser
- * (currently at GitHub)
+ * Open Pump.io's User Guide in web browser
+ * (currently at GitHub.com)
  *
  */
-void MainWindow::visitFAQ()
+void MainWindow::visitPumpGuide()
 {
-    qDebug() << "Opening Pump.io FAQ in browser";
-    QDesktopServices::openUrl(QUrl("https://github.com/e14n/pump.io/wiki/FAQ"));
+    qDebug() << "Opening Pump.io User Guide in browser";
+    QDesktopServices::openUrl(QUrl("https://github.com/e14n/pump.io/wiki/User-Guide"));
 }
 
 void MainWindow::visitTips()
@@ -2230,10 +2439,13 @@ void MainWindow::visitUserList()
 void MainWindow::aboutDianara()
 {
     QMessageBox::about(this, tr("About Dianara"),
-                       "<b>Dianara v1.2.4</b><br>"
-                       "Copyright 2012-2014  JanKusanagi<br><br>"
-                       "<a href=\"http://jancoding.wordpress.com/dianara\">"
-                       "http://jancoding.wordpress.com/dianara</a><br><br>"
+                       QString("<b>Dianara v%1</b>").arg(qApp->applicationVersion())
+                       + "<br>"
+                         "Copyright 2012-2014  JanKusanagi<br><br>"
+                         "<a href=\"http://jancoding.wordpress.com/dianara\">"
+                         "http://jancoding.wordpress.com/dianara</a><br>"
+                         "<br>"
+                         "<br>"
 
                        + tr("Dianara is a pump.io social networking client.")
                        + "<br><br>"
@@ -2242,17 +2454,24 @@ void MainWindow::aboutDianara()
                             "create new posts, upload pictures and "
                             "other media, interact with posts, manage "
                             "your contacts and follow new people.")
-                       + "<br><br>"
+                       + "<br>"
 
-                       + tr("Thanks to all the testers, translators and packagers, "
-                            "who help make Dianara better!")
-                       + "<br><br>"
+                         "<hr>" // ---
+                         "<br>"
 
                        + tr("English translation by JanKusanagi.",
                             "TRANSLATORS: Change this with your language and name. "
                             "If there was another translator before you, add your "
                             "name after theirs ;)")
-                       + "<br><br>"
+                       + "<br>"
+                         "<br>"
+
+                       + tr("Thanks to all the testers, translators and packagers, "
+                            "who help make Dianara better!")
+                       + "<br>"
+
+                         "<hr>" // ---
+                         "<br>"
 
                        + tr("Dianara is licensed under the GNU GPL license, and "
                             "uses some Oxygen icons: http://www.oxygen-icons.org/ "
@@ -2352,7 +2571,10 @@ void MainWindow::quitProgram()
         this->directTimeline->clearTimeLineContents();
         this->activityTimeline->clearTimeLineContents();
         this->favoritesTimeline->clearTimeLineContents();
+
         this->meanwhileFeed->clearContents();
+        this->mentionsFeed->clearContents();
+        this->actionsFeed->clearContents();
 
         this->publisher->deleteLater();
         this->contactManager->deleteLater();
@@ -2361,7 +2583,6 @@ void MainWindow::quitProgram()
                           | QEventLoop::ExcludeSocketNotifiers);
 
         qApp->closeAllWindows();
-        //qApp->quit();
 
         //qApp->processEvents();
         std::cout << "All windows closed, bye! o/\n";
