@@ -145,7 +145,9 @@ public slots:
 
     void setTitleAndTrayInfo(int currentTab);
     void setMinorFeedTitle(int newItemsCount, int newHighlightedItemsCount);
+    void setMentionsFeedTitle(int newItemsCount, int newHighlightedItemsCount);
     void notifyMinorFeedUpdate(int newItemsCount, int highlightedCount);
+    void notifyMentionsFeedUpdate(int newItemsCount, int highlightedCount);
 
     void storeAvatar(QByteArray avatarData, QUrl avatarUrl);
     void storeImage(QByteArray imageData, QUrl imageUrl);
@@ -163,9 +165,14 @@ public slots:
     void toggleStatusBar(bool shown);
     void toggleFullscreen(bool enabled);
 
+    void toggleMeanwhileFeed();
+    void toggleMentionsFeed();
+    void toggleActionsFeed();
+
 
     void visitWebSite();
-    void visitFAQ();
+    void visitBugTracker();
+    void visitPumpGuide();
     void visitTips();
     void visitUserList();
     void aboutDianara();
@@ -197,8 +204,9 @@ private:
     QAction *sessionUpdateDirectTimeline;
     QAction *sessionUpdateActivityTimeline;
     QAction *sessionUpdateFavoritesTimeline;
-    QAction *sessionUpdateMinorFeed;
-    QAction *sessionUpdateAllTimelines;
+    QAction *sessionUpdateMinorFeedMain;
+    QAction *sessionUpdateMinorFeedDirect;
+    QAction *sessionUpdateMinorFeedActivity;
     QAction *sessionAutoUpdates;
     QAction *sessionMarkAllAsRead;
     QAction *sessionPostNote;
@@ -217,7 +225,8 @@ private:
 
     QAction *helpBasicHelp;
     QAction *helpVisitWebsite;
-    QAction *helpVisitPumpFAQ;
+    QAction *helpVisitBugTracker;
+    QAction *helpVisitPumpGuide;
     QAction *helpVisitPumpTips;
     QAction *helpVisitPumpUserList;
     QAction *helpAbout;
@@ -240,6 +249,10 @@ private:
     QVBoxLayout *userInfoLayout;
     QToolBox *leftPanel;
 
+    QAction *showMeanwhileFeed;
+    QAction *showMentionsFeed;
+    QAction *showActionsFeed;
+
     QWidget *rightSideWidget;
     QVBoxLayout *rightLayout;
     QTabWidget *tabWidget;
@@ -275,6 +288,8 @@ private:
     FDNotifications *fdNotifier;
 
     MinorFeed *meanwhileFeed;
+    MinorFeed *mentionsFeed;
+    MinorFeed *actionsFeed;
 
     int postsPerPageMain;
     TimeLine *mainTimeline;
@@ -299,6 +314,7 @@ private:
     bool firstRun;
     QString dataDirectory; // will have /images and /avatars
     bool reallyQuitProgram;
+    bool initializationComplete;
 
     int updateInterval;
     QTimer *updateTimer;
@@ -311,6 +327,7 @@ private:
     bool publicPosts;
 
     QString oldStatusBarMessage;
+    QString previousStatusMessageForMinorFeed;
 
     // user account-related data
     QString userID;
