@@ -21,25 +21,31 @@
 #include "minorfeed.h"
 
 
-MinorFeed::MinorFeed(PumpController *pumpController,
+MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
+                     PumpController *pumpController,
                      GlobalObject *globalObject,
                      FilterChecker *filterChecker,
                      QWidget *parent) : QFrame(parent)
 {
+    this->feedType = minorFeedType;
     this->pController = pumpController;
     this->globalObj = globalObject;
     this->fChecker = filterChecker;
     this->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
+    this->setContentsMargins(0, 0, 0, 0);
 
     // Layout for the items
     itemsLayout = new QVBoxLayout();
     itemsLayout->setContentsMargins(0, 0, 0, 0);
+    itemsLayout->setSpacing(1); // Very small spacing
     itemsLayout->setAlignment(Qt::AlignTop);
 
     // Separator frame, to mark where new items end
-    separatorFrame = new QFrame();
+    separatorFrame = new QFrame(this);
     separatorFrame->setFrameStyle(QFrame::HLine);
     separatorFrame->setMinimumHeight(28);
+    separatorFrame->setContentsMargins(0, 8, 0, 8);
+    separatorFrame->hide();
 
     // Button to get more items (older stuff)
     getMoreButton = new QPushButton(QIcon::fromTheme("list-add",
@@ -56,7 +62,7 @@ MinorFeed::MinorFeed(PumpController *pumpController,
 
     // Main layout
     mainLayout = new QVBoxLayout();
-    mainLayout->setContentsMargins(1, 2, 1, 2);
+    mainLayout->setContentsMargins(1, 1, 1, 1);
     mainLayout->setAlignment(Qt::AlignTop);
     mainLayout->addLayout(itemsLayout);
     mainLayout->addWidget(getMoreButton);
@@ -88,10 +94,37 @@ MinorFeed::MinorFeed(PumpController *pumpController,
 
     // Remember what was the newest activity last time
     QSettings settings;
-    settings.beginGroup("MinorFeedState");
-    this->previousNewestActivityId = settings.value("previousNewestItemId", "").toString();
+    settings.beginGroup("MinorFeedStates");
+    switch (this->feedType)
+    {
+    case PumpController::MinorFeedMainRequest:
+        this->previousNewestActivityId = settings
+                                         .value("previousNewestItemIdMain")
+                                         .toString();
+        break;
+
+    case PumpController::MinorFeedDirectRequest:
+        this->previousNewestActivityId = settings
+                                         .value("previousNewestItemIdDirect")
+                                         .toString();
+        break;
+
+    case PumpController::MinorFeedActivityRequest:
+        this->previousNewestActivityId = settings
+                                         .value("previousNewestItemIdActivity")
+                                         .toString();
+        break;
+
+    default:
+        qDebug() << "MinorFeed created with wrong type:" << this->feedType;
+    }
     settings.endGroup();
 
+
+    // Sync all avatar's follow state when there are changes in the Following list
+    connect(pController, SIGNAL(followingListChanged()),
+            this, SLOT(updateAvatarFollowStates()));
+
     qDebug() << "MinorFeed created";
 }
 
@@ -99,12 +132,31 @@ MinorFeed::MinorFeed(PumpController *pumpController,
 MinorFeed::~MinorFeed()
 {
     QSettings settings;
+    settings.beginGroup("MinorFeedStates");
 
-    settings.beginGroup("MinorFeedState");
-    settings.setValue("previousNewestItemId", this->previousNewestActivityId);
+    switch (this->feedType)
+    {
+    case PumpController::MinorFeedMainRequest:
+        settings.setValue("previousNewestItemIdMain",
+                          this->previousNewestActivityId);
+        break;
+
+    case PumpController::MinorFeedDirectRequest:
+        settings.setValue("previousNewestItemIdDirect",
+                          this->previousNewestActivityId);
+        break;
+
+    case PumpController::MinorFeedActivityRequest:
+        settings.setValue("previousNewestItemIdActivity",
+                          this->previousNewestActivityId);
+        break;
+
+    default:
+        qDebug() << "MinorFeed type was wrong";
+    }
     settings.endGroup();
 
-    qDebug() << "MinorFeed destroyed";
+    qDebug() << "MinorFeed destroyed; Type:" << this->feedType;
 }
 
 
@@ -146,10 +198,11 @@ void MinorFeed::updateFuzzyTimestamps()
 }
 
 
-
+/*******************************************************************************/
 /*******************************************************************************/
 /********************************** SLOTS **************************************/
 /*******************************************************************************/
+/*******************************************************************************/
 
 
 /*
@@ -159,7 +212,7 @@ void MinorFeed::updateFuzzyTimestamps()
 void MinorFeed::updateFeed()
 {
     this->feedOffset = 0;
-    this->pController->getMinorFeed();
+    this->pController->getMinorFeed(this->feedType);
     //this->pController->getMinorFeedProper(this->prevLink);
 }
 
@@ -169,8 +222,25 @@ void MinorFeed::updateFeed()
  */
 void MinorFeed::getMoreActivities()
 {
-    this->feedOffset += 50;
-    this->pController->getMinorFeed(feedOffset);
+    int feedJumpSize = 50; // TMP, until getMinorFeedProper() is used; FIXME
+    switch (this->feedType)
+    {
+    case PumpController::MinorFeedMainRequest:
+        feedJumpSize = 50;
+        break;
+
+    case PumpController::MinorFeedDirectRequest:
+    case PumpController::MinorFeedActivityRequest:
+        feedJumpSize = 20;
+        break;
+
+    default:
+        break;
+    }
+
+    this->feedOffset += feedJumpSize;
+    this->pController->getMinorFeed(this->feedType,
+                                    this->feedOffset);
     //this->pController->getMinorFeedProper(this->nextLink);
 }
 
@@ -313,3 +383,12 @@ void MinorFeed::decreaseNewItemsCount(bool wasHighlighted)
 
     emit newItemsCountChanged(newItemsCount, newHighlightedItemsCount);
 }
+
+
+void MinorFeed::updateAvatarFollowStates()
+{
+    foreach (MinorFeedItem *feedItem, itemsInFeed)
+    {
+        feedItem->syncAvatarFollowState();
+    }
+}
