@@ -42,7 +42,8 @@ class MinorFeed : public QFrame
     Q_OBJECT
 
 public:
-    explicit MinorFeed(PumpController *pumpController,
+    explicit MinorFeed(PumpController::requestTypes minorFeedType,
+                       PumpController *pumpController,
                        GlobalObject *globalObject,
                        FilterChecker *filterChecker,
                        QWidget *parent = 0);
@@ -66,11 +67,14 @@ public slots:
 
     void decreaseNewItemsCount(bool wasHighlighted);
 
+    void updateAvatarFollowStates();
+
 
 private:
     QString prevLink;
     QString nextLink;
 
+    PumpController::requestTypes feedType;
     int feedOffset;
 
     QString previousNewestActivityId;
