@@ -53,11 +53,10 @@ public:
 
     void setItemAsNew(bool isNew);
     void setFuzzyTimeStamp();
+    void syncAvatarFollowState();
 
     int getItemHighlightType();
 
-    static bool canDisplayObject(QString objectType);
-
     
 signals:
     void itemRead(bool wasHighlighted);
@@ -91,6 +90,9 @@ private:
     QVariantMap originalObjectMap;
     QVariantMap inReplyToMap;
 
+    AvatarButton *targetAvatarButton;
+    bool haveTargetAvatar;
+
     bool itemIsNew;
     int itemHighlightType;
     QString createdAtTimestamp;
