@@ -227,28 +227,29 @@ QString MiscHelpers::fixLongName(QString name)
 
 /*
  * Return a pretty string with the size of a file, like
- * "33 KiB", "512 bytes" or "3 MiB"
+ * "33 KiB", "512 bytes" or "3,2 MiB"
  *
  */
 QString MiscHelpers::fileSizeString(QString fileURI)
 {
     QFileInfo fileInfo(fileURI);
-    int fileSize = fileInfo.size();
+    double fileSize = fileInfo.size();
 
     QString sizeUnit = tr("bytes");
     if (fileSize > 1024) // if > 1024 bytes, transform to KiB
     {
-        fileSize /= 1024;
+        fileSize /= 1024.0;
         sizeUnit = "KiB";
     }
     if (fileSize > 1024) // if > 1024 KiB, transform to MiB
     {
-        fileSize /= 1024;
+        fileSize /= 1024.0;
         sizeUnit = "MiB";
     }
 
 
-    return QString("%1 %2").arg(fileSize).arg(sizeUnit);
+    // Return with 0 padding and 2 decimal precision
+    return QString("%1 %2").arg(fileSize, 0, 'f', 2).arg(sizeUnit);
 }
 
 
@@ -351,7 +352,7 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
     //////////////////////////////////////// Remove <span style=...> from links
     QRegExp linkStyleRE("<a href=.*>.*</a>");
     linkStyleRE.setMinimal(true);
-    QRegExp spanRE("<span style=.*>(.*)</span>");
+    QRegExp spanRE("<span style=.*>(.*)</span>"); // FIXME: remove ONLY color info
     spanRE.setMinimal(true);
 
     int pos = 0;
@@ -422,7 +423,9 @@ QString MiscHelpers::quotedText(QString author, QString content)
     textDocument.setHtml(content);
 
     content = textDocument.toPlainText().trimmed();
-    content.replace("\n", "<br>");
+    content.replace("<", "&lt;"); // back to HTML entities
+    content.replace(">", "&gt;");
+    content.replace("\n", "<br>"); // Important to replace this AFTER < and >
 
     QString quoteHtml = "&gt;&gt; <b><u>"+ author + ":</u></b>"  // >> + name
                         "<blockquote>"
