@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,11 +22,15 @@
 #define NOTIFICATIONS_H
 
 #include <QObject>
-#include <QtDBus>
 #include <QVariantMap>
 #include <QString>
 #include <QIcon>
 
+#ifdef QT_DBUS_LIB
+#include <QtDBus>
+#endif
+
+
 #include <QDebug>
 
 class FDNotifications : public QObject
@@ -34,7 +38,7 @@ class FDNotifications : public QObject
     Q_OBJECT
 
 public:
-    FDNotifications();
+    FDNotifications(QObject* parent);
     ~FDNotifications();
 
     bool areNotificationsAvailable();
@@ -68,7 +72,9 @@ public slots:
 
 
 private:
+#ifdef QT_DBUS_LIB
     QDBusConnection *bus;
+#endif
 
     bool notificationsAvailable;
 
