@@ -40,18 +40,21 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
 
     this->rangeLabel = new QLabel();
 
-    this->goButton = new QPushButton(QIcon::fromTheme("go-next-view-page"),
+    this->goButton = new QPushButton(QIcon::fromTheme("go-next-view-page",
+                                                      QIcon(":/images/button-share.png")),
                                      tr("&Go"));
     connect(goButton, SIGNAL(clicked()),
             this, SLOT(goToPage()));
 
-    this->goToLastButton = new QPushButton(QIcon::fromTheme("go-last-view-page"),
+    this->goToLastButton = new QPushButton(QIcon::fromTheme("go-last-view-page",
+                                                            QIcon(":/images/button-share.png")),
                                            tr("Go to &last page"));
     connect(goToLastButton, SIGNAL(clicked()),
             this, SLOT(goToLastPage()));
 
 
-    this->closeButton = new QPushButton(QIcon::fromTheme("window-close"),
+    this->closeButton = new QPushButton(QIcon::fromTheme("window-close",
+                                                         QIcon(":/images/button-cancel.png")),
                                         tr("&Cancel"));
     connect(closeButton, SIGNAL(clicked()),
             this, SLOT(hide()));
@@ -70,17 +73,20 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     topLayout->addWidget(pageNumberSpinbox);
     topLayout->addSpacing(8);
     topLayout->addWidget(rangeLabel);
-    topLayout->addSpacing(8);
+    topLayout->addSpacing(24);
     topLayout->addWidget(goButton);
 
     this->bottomLayout = new QHBoxLayout();
     bottomLayout->addWidget(goToLastButton);
+    bottomLayout->addSpacing(8);
     bottomLayout->addWidget(closeButton);
 
 
     this->mainLayout = new QVBoxLayout();
     mainLayout->addLayout(topLayout);
+    mainLayout->addSpacing(8);
     mainLayout->addStretch(1);
+    mainLayout->addSpacing(8);
     mainLayout->addLayout(bottomLayout);
     this->setLayout(mainLayout);
 
