@@ -188,7 +188,7 @@ void PeopleWidget::updateAllContactsList(QString listType,
     }
     qDebug() << "PeopleWidget: received list of Following; updating...";
 
-    if (totalReceivedCount == 200)  // Only on first batch
+    if (totalReceivedCount <= 200)  // Only on first batch
     {
         this->itemModel->clear();
     }
