@@ -147,59 +147,80 @@ Post::Post(ASActivity *activity,
     detailsFont.setPointSize(detailsFont.pointSize() - 2); // FIXME: check size first
 
 
-    /////////////////////////////////////////////////// Left column, post Meta info
-
-    // Is the post a reshare? Indicate who shared it
+    // Is the post a reshare? Indicate who shared it with a wide label at the top
     postIsSharedLabel = new QLabel(this); // With parent to avoid leaks
+                                          // Needs to be initialized even if
+                                          // unused, for setFuzzyTimestamps()
     postIsSharedLabel->hide();
     if (activity->isShared())
     {
         postIsSharedLabel->show();
         this->postSharedById = activity->getSharedById();
+        postShareTime = activity->getUpdatedAt();
 
-        QString sharedByName = MiscHelpers::fixLongName(activity->getSharedByName());
-        postIsSharedLabel->setText("<p>"
-                                   + QString::fromUtf8("\342\231\272  ") // Recycling symbol
-                                   + tr("Via %1").arg(sharedByName)
-                                   + QString::fromUtf8("  \342\231\272")
-                                   + "</p> &nbsp;");
+        QString sharedByName = activity->getSharedByName();
+        postShareInfoString = QString::fromUtf8("\342\231\272 &nbsp; &nbsp; ") // Recycling symbol
+                                                + tr("Via %1").arg("<a href=\""
+                                                + activity->author()->getUrl()
+                                                + "\">"
+                                                + sharedByName
+                                                + "</a> - ");
+
+        // Fuzzy time is added here, in setFuzzyTimestamps()
+
+        this->postSharedToCCString.clear();
+        if (!activity->getToString().isEmpty())
+        {
+            postSharedToCCString.append(" - " + tr("To") + ": "
+                                        + activity->getToString());
+        }
+
+        if (!activity->getCCString().isEmpty())
+        {
+            postSharedToCCString.append(" - " + tr("Cc") + ": "
+                                        + activity->getCCString());
+        }
+
+
+        postIsSharedLabel->setText(postShareInfoString);
         postIsSharedLabel->setWordWrap(true);
-        postIsSharedLabel->setAlignment(Qt::AlignCenter);
+        postIsSharedLabel->setOpenExternalLinks(true);
+        postIsSharedLabel->setAlignment(Qt::AlignHCenter | Qt::AlignTop);
         postIsSharedLabel->setFont(detailsFont);
         postIsSharedLabel->setForegroundRole(QPalette::Text);
         postIsSharedLabel->setBackgroundRole(QPalette::Base);
         postIsSharedLabel->setAutoFillBackground(true);
         postIsSharedLabel->setFrameStyle(QFrame::Panel | QFrame::Raised);
-        postIsSharedLabel->setSizePolicy(QSizePolicy::Ignored,
-                                         QSizePolicy::Expanding);
+        connect(postIsSharedLabel, SIGNAL(linkHovered(QString)),
+                this, SLOT(showHighlightedUrl(QString)));
+
+        QString shareTooltip = "<img align=\"left\" src=\""
+                               + MiscHelpers::getCachedAvatarFilename(activity->getSharedByAvatar())
+                               + "\" width=\"48\" />";
+        shareTooltip.append("&nbsp;&nbsp;<b>"
+                            + sharedByName
+                            + "</b><br>");
+        shareTooltip.append("&nbsp;&nbsp;<i>"
+                            + this->postSharedById
+                            + "</i>");
 
 
-        sharedByTooltipString = "<img align=\"left\" src=\""
-                                + MiscHelpers::getCachedAvatarFilename(activity->getSharedByAvatar())
-                                + "\" width=\"48\" />";
-        sharedByTooltipString.append("&nbsp;&nbsp;<b>"
-                                     + sharedByName
-                                     + "</b><br>");
-        sharedByTooltipString.append("&nbsp;&nbsp;<i>"
-                                     + this->postSharedById
-                                     + "</i>");
-
-        shareTime = activity->getUpdatedAt();
-        QString exactShareTime = Timestamp::localTimeDate(shareTime);
-        sharedByTooltipString.append("<br><hr><br>"
-                                     + tr("Shared on %1").arg(exactShareTime));
-        // Fuzzy timestamp will be inserted here, in setFuzzyTimestamps()
+        QString exactShareTime = Timestamp::localTimeDate(postShareTime);
+        shareTooltip.append("<br><hr><br>"
+                            + tr("Shared on %1").arg(exactShareTime));
         if (!generator.isEmpty())
         {
-            sharedByGeneratorString = " " + tr("using %1").arg(generator);
+            shareTooltip.append("<br>"
+                                + tr("Using %1",
+                                     "1=Program used for posting or sharing")
+                                  .arg(generator));
             generator.clear(); // So it's not used in the post timestamp tooltip!
         }
-        postIsSharedLabel->setToolTip(sharedByTooltipString);
-        leftColumnLayout->addWidget(postIsSharedLabel);
-        leftColumnLayout->addSpacing(2);
-    }    
+        postIsSharedLabel->setToolTip(shareTooltip);
+    }
 
 
+    /////////////////////////////////////////////////// Left column, post Meta info
 
     // Different frame if post is ours
     if (postAuthorId == pController->currentUserId())
@@ -315,34 +336,61 @@ Post::Post(ASActivity *activity,
     {
         postUpdatedAtString.clear();
     }
-    // Format is "Combined date and time in UTC", like "2012-02-07T01:32:02Z"
-    // as specified in ISO 8601 http://en.wikipedia.org/wiki/ISO_8601
-    QString dateGeneratorTooltip = tr("Type", "As in: type of object") + ": "
+    // Timestamp format is "Combined date and time in UTC", like
+    // "2012-02-07T01:32:02Z" as per ISO8601 http://en.wikipedia.org/wiki/ISO_8601
+
+
+    QString postCreatedAtExtendedText = tr("Posted on %1",
+                                           "1=Date")
+                                        .arg(Timestamp::localTimeDate(postCreatedAtString));
+    QString dateGeneratorTooltip = tr("Type",
+                                      "As in: type of object") + ": "
                                    + postTypeString + "\n"
-                                   + tr("Posted on %1", "1=Date")
-                                     .arg(Timestamp::localTimeDate(postCreatedAtString));
+                                   + postCreatedAtExtendedText;
+    QString postedWithGeneratorString;
     if (!generator.isEmpty())
     {
-        dateGeneratorTooltip.append("\n" +
-                                    tr("Using %1",
-                                       "1=Program used for posting").arg(generator));
+        postedWithGeneratorString = tr("Using %1",
+                                       "1=Program used for posting or sharing").arg(generator);
+        dateGeneratorTooltip.append("\n" + postedWithGeneratorString);
     }
     if (!postUpdatedAtString.isEmpty())
     {
         // Using \n instead of <br> because I don't want this tooltip to be HTML (wrapped)
+        QString modifiedOn = tr("Modified on %1")
+                             .arg(Timestamp::localTimeDate(postUpdatedAtString));
+        postCreatedAtExtendedText.append("<br>"
+                                         + modifiedOn);
         dateGeneratorTooltip.append("\n\n"
-                                    + tr("Modified on %1")
-                                      .arg(Timestamp::localTimeDate(postUpdatedAtString)));
+                                    + modifiedOn);
     }
 
     postCreatedAtLabel = new HClabel();
+    postCreatedAtLabel->setExtendedText(postCreatedAtExtendedText);
     postCreatedAtLabel->setToolTip(dateGeneratorTooltip);
-    postCreatedAtLabel->setTextFormat(Qt::PlainText);
     postCreatedAtLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postCreatedAtLabel->setFont(detailsFont);
+    postCreatedAtLabel->setSizePolicy(QSizePolicy::Ignored,
+                                      QSizePolicy::Expanding);
     leftColumnLayout->addWidget(postCreatedAtLabel);
+
+    // Generator app, if enabled to display directly
+    if (!generator.isEmpty() && globalObj->getPostShowExtraInfo())
+    {
+        this->postGeneratorLabel = new QLabel(//QString::fromUtf8("\342\232\231 ") // Gear symbol
+                                              QString::fromUtf8("\342\214\250 ") // Keyboard symbol
+                                              + generator);
+        postGeneratorLabel->setFont(detailsFont);
+        //postGeneratorLabel->setWordWrap(true);
+        //postGeneratorLabel->setTextFormat(Qt::RichText);
+        postGeneratorLabel->setSizePolicy(QSizePolicy::Ignored,
+                                          QSizePolicy::Minimum);
+        leftColumnLayout->addWidget(postGeneratorLabel);
+    }
+
     leftColumnLayout->addSpacing(4);
 
+
     // Location information, if any
     QString location = activity->object()->getLocationName();
     if (!location.isEmpty())
@@ -350,39 +398,50 @@ Post::Post(ASActivity *activity,
         this->postLocationLabel = new HClabel(tr("In")
                                               + ": <b>" + location + "</b>");
         postLocationLabel->setFont(detailsFont);
-        postLocationLabel->setToolTip(activity->object()->getLocationTooltip());
+        postLocationLabel->setSizePolicy(QSizePolicy::Ignored,
+                                         QSizePolicy::Expanding);
+        postLocationLabel->setExtendedText(activity->object()->getLocationTooltip());
+        postLocationLabel->setToolTip("<font size=\"+6\">"
+                                      + QString::fromUtf8("\342\214\226 ") // Position indicator symbol
+                                      + "</font>"
+                                      + activity->object()->getLocationTooltip());
         leftColumnLayout->addWidget(postLocationLabel);
         leftColumnLayout->addSpacing(2);
     }
 
-    if (!activity->getToString().isEmpty())
+    if (!activity->isShared())  // When shared, To/CC are shown with share info
     {
-        this->postToLabel = new QLabel(tr("To") + ": "
-                                       + activity->getToString());
-        postToLabel->setWordWrap(true);
-        postToLabel->setFont(detailsFont);
-        postToLabel->setOpenExternalLinks(true);
-        postToLabel->setSizePolicy(QSizePolicy::Ignored,
-                                   QSizePolicy::Minimum);
+        if (!activity->getToString().isEmpty())
+        {
+            this->postToLabel = new QLabel(tr("To") + ": "
+                                           + activity->getToString()
+                                           + " &nbsp;"); // Small hack to try to ensure full visibility
+            postToLabel->setWordWrap(true);
+            postToLabel->setOpenExternalLinks(true);
+            postToLabel->setSizePolicy(QSizePolicy::Ignored,
+                                       QSizePolicy::Expanding);
+            postToLabel->setFont(detailsFont);
 
-        leftColumnLayout->addWidget(postToLabel);
-        connect(postToLabel, SIGNAL(linkHovered(QString)),
-                this, SLOT(showHighlightedUrl(QString)));
-    }
+            leftColumnLayout->addWidget(postToLabel);
+            connect(postToLabel, SIGNAL(linkHovered(QString)),
+                    this, SLOT(showHighlightedUrl(QString)));
+        }
 
-    if (!activity->getCCString().isEmpty())
-    {
-        this->postCCLabel = new QLabel(tr("CC") + ": "
-                                       + activity->getCCString());
-        postCCLabel->setWordWrap(true);
-        postCCLabel->setFont(detailsFont);
-        postCCLabel->setOpenExternalLinks(true);
-        postCCLabel->setSizePolicy(QSizePolicy::Ignored,
-                                   QSizePolicy::Minimum);
+        if (!activity->getCCString().isEmpty())
+        {
+            this->postCCLabel = new QLabel(tr("Cc") + ": "
+                                           + activity->getCCString()
+                                           + " &nbsp;");
+            postCCLabel->setWordWrap(true);
+            postCCLabel->setOpenExternalLinks(true);
+            postCCLabel->setSizePolicy(QSizePolicy::Ignored,
+                                       QSizePolicy::Expanding);
+            postCCLabel->setFont(detailsFont);
 
-        leftColumnLayout->addWidget(postCCLabel);
-        connect(postCCLabel, SIGNAL(linkHovered(QString)),
-                this, SLOT(showHighlightedUrl(QString)));
+            leftColumnLayout->addWidget(postCCLabel);
+            connect(postCCLabel, SIGNAL(linkHovered(QString)),
+                    this, SLOT(showHighlightedUrl(QString)));
+        }
     }
 
     leftColumnLayout->addSpacing(4);
@@ -393,12 +452,17 @@ Post::Post(ASActivity *activity,
     this->postSharesUrl = activity->object()->getSharesUrl();
 
 
-    // Set this QLabels with parent=this, since we're gonna hide them right away
+    // Set these labels with parent=this, since we're gonna hide them right away
     // They'll be reparented to the layout, but not having a parent before that
     // would cause visual glitches
     postLikesCountLabel = new HClabel("", this);
     postLikesCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postLikesCountLabel->setFont(detailsFont);
+    postLikesCountLabel->setOpenExternalLinks(true);
+    postLikesCountLabel->setSizePolicy(QSizePolicy::Ignored,
+                                       QSizePolicy::Expanding);
+    connect(postLikesCountLabel, SIGNAL(linkHovered(QString)),
+            this, SLOT(showHighlightedUrl(QString)));
     leftColumnLayout->addWidget(postLikesCountLabel);
     postLikesCountLabel->hide();
     int likesCount = activity->object()->getLikesCount().toInt();
@@ -415,11 +479,16 @@ Post::Post(ASActivity *activity,
     this->setCommentsLabel(commentsCount);
 
 
-    postResharesCountLabel = new HClabel("", this);
-    postResharesCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-    postResharesCountLabel->setFont(detailsFont);
-    leftColumnLayout->addWidget(postResharesCountLabel);
-    postResharesCountLabel->hide();
+    postSharesCountLabel = new HClabel("", this);
+    postSharesCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+    postSharesCountLabel->setFont(detailsFont);
+    postSharesCountLabel->setOpenExternalLinks(true);
+    postSharesCountLabel->setSizePolicy(QSizePolicy::Ignored,
+                                        QSizePolicy::Expanding);
+    connect(postSharesCountLabel, SIGNAL(linkHovered(QString)),
+            this, SLOT(showHighlightedUrl(QString)));
+    leftColumnLayout->addWidget(postSharesCountLabel);
+    postSharesCountLabel->hide();
     int sharesCount = activity->object()->getSharesCount().toInt();
     this->setSharesLabel(sharesCount);
 
@@ -701,6 +770,12 @@ Post::Post(ASActivity *activity,
 
         this->groupInfoLabel = new QLabel(tr("%1 members in the group")
                                           .arg(activity->object()->getMemberCount()));
+#ifdef GROUPSUPPORT
+        groupInfoLabel->setText(groupInfoLabel->text()
+                                + "<br><a href=\""
+                                + activity->object()->getId()
+                                + "\">-GROUP ID-</a>");
+#endif
         groupInfoLabel->setWordWrap(true);
         groupInfoLabel->setFont(detailsFont);
         groupInfoLabel->setAlignment(Qt::AlignCenter);
@@ -757,12 +832,25 @@ Post::Post(ASActivity *activity,
 
     mainLayout = new QHBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);   // Minimal margins
-    mainLayout->addWidget(leftColumnFrame,   2);  // stretch 2/13
-    mainLayout->addWidget(rightColumnFrame, 11);  // stretch 11/13
-
+    mainLayout->setSpacing(1);
     mainLayout->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-    this->setLayout(mainLayout);
+    mainLayout->addWidget(leftColumnFrame,   1);  // stretch 1/9
+    mainLayout->addWidget(rightColumnFrame,  8);  // stretch 8/9
 
+    if (activity->isShared())
+    {
+        outerLayout = new QVBoxLayout();
+        outerLayout->setContentsMargins(0, 0, 0, 0);
+        outerLayout->setSpacing(0);
+        outerLayout->setAlignment(Qt::AlignTop);
+        outerLayout->addWidget(postIsSharedLabel, 0); // Ensure it's small
+        outerLayout->addLayout(mainLayout,        10);
+        this->setLayout(outerLayout);
+    }
+    else
+    {
+        this->setLayout(mainLayout);
+    }
 
     this->minMaxHeight = 400; // Initialize, but it'll be set before it's used anyway
 
@@ -910,7 +998,7 @@ void Post::onResizeOrShow()
 void Post::setPostHeight()
 {
     int height = qMax(postText->document()->size().toSize().height() + 12, // +12px error margin
-                      60); // Minimum height of 60
+                      64); // Minimum height of 64
 
     height = qMin(height, this->minMaxHeight); // Don't allow a post to be too tall
 
@@ -969,21 +1057,8 @@ void Post::setLikes(QVariantList likesList, int likesCount)
 {
     if (likesList.size() > 0)
     {
-        QString peopleString; // FIXME: repeated in Comment(), move to method
-        foreach (QVariant likesMap, likesList)
-        {
-            QString name = likesMap.toMap().value("displayName").toString();
-            if (name.isEmpty())
-            {
-                name = ASPerson::cleanupId(likesMap.toMap()
-                                                   .value("id")
-                                                   .toString()); // fallback
-            }
-            peopleString.append(name + ", ");
-        }
-
-        // Remove last comma and add "like this"
-        peopleString.remove(-2, 2); // Last 2 characters
+        QString peopleString = ASObject::personStringFromList(likesList,
+                                                              likesCount);
 
         QString likesString;
         if (likesList.size() == 1)
@@ -996,9 +1071,10 @@ void Post::setLikes(QVariantList likesList, int likesCount)
             likesString = tr("%1 like this",
                              "More than one person").arg(peopleString);
         }
-        likesString.prepend("<b></b>"); // Turn the tooltip into rich text
 
-        this->postLikesCountLabel->setToolTip(likesString);
+        this->postLikesCountLabel->setExtendedText(likesString);
+        this->postLikesCountLabel->setToolTip("<b></b>" // Turn the tooltip into rich text
+                                              + likesString);
     }
 
     // TMP/FIXME this can set the number to lower than initially set
@@ -1024,13 +1100,13 @@ void Post::setLikesLabel(int likesCount)
     {
         if (likesCount == 1)
         {
-            postLikesCountLabel->setText(QString::fromUtf8("\342\231\245 ") // heart symbol
-                                  + tr("1 like"));
+            postLikesCountLabel->setBaseText(QString::fromUtf8("\342\231\245 ") // Heart symbol
+                                             + tr("1 like"));
         }
         else
         {
-            postLikesCountLabel->setText(QString::fromUtf8("\342\231\245 ") // heart symbol
-                                  + tr("%1 likes").arg(likesCount));
+            postLikesCountLabel->setBaseText(QString::fromUtf8("\342\231\245 ") // heart symbol
+                                             + tr("%1 likes").arg(likesCount));
         }
         postLikesCountLabel->show();
     }
@@ -1125,28 +1201,24 @@ void Post::setShares(QVariantList sharesList, int sharesCount)
 {
     if (sharesList.size() > 0)
     {
-        QString peopleString;
-        foreach (QVariant sharesMap, sharesList)
-        {
-            peopleString = sharesMap.toMap().value("displayName").toString() + ", "
-                           + peopleString;
-        }
-
-        // Remove last comma and add "shared this"
-        peopleString.remove(-2, 2); // Last 2 characters
+        QString peopleString = ASObject::personStringFromList(sharesList,
+                                                              sharesCount);
 
         QString sharesString;
         if (sharesList.size() == 1)
         {
-            sharesString = tr("%1 shared this", "%1 = One person name").arg(peopleString);
+            sharesString = tr("%1 shared this",
+                              "%1 = One person name").arg(peopleString);
         }
         else
         {
-            sharesString = tr("%1 shared this", "%1 = Names for more than one person").arg(peopleString);
+            sharesString = tr("%1 shared this",
+                              "%1 = Names for more than one person").arg(peopleString);
         }
-        sharesString.prepend("<b></b>");  // So that the label is rich text, wordwrapped
 
-        this->postResharesCountLabel->setToolTip(sharesString);
+        this->postSharesCountLabel->setExtendedText(sharesString);
+        this->postSharesCountLabel->setToolTip("<b></b>" // So the tooltip is rich text, wordwrapped
+                                               + sharesString);
     }
 
     // TMP/FIXME this can set the number to lower than initially set
@@ -1168,21 +1240,21 @@ void Post::setSharesLabel(int resharesCount)
     {
         if (resharesCount == 1)
         {
-            postResharesCountLabel->setText(QString::fromUtf8("\342\231\273 ") // recycle symbol
-                                      + tr("Shared once"));
+            postSharesCountLabel->setBaseText(QString::fromUtf8("\342\231\273 ") // Recycle symbol
+                                              + tr("Shared once"));
         }
         else
         {
-            postResharesCountLabel->setText(QString::fromUtf8("\342\231\273 ") // recycle symbol
-                                      + tr("Shared %1 times").arg(resharesCount));
+            postSharesCountLabel->setBaseText(QString::fromUtf8("\342\231\273 ") // Recycle symbol
+                                              + tr("Shared %1 times").arg(resharesCount));
         }
 
-        postResharesCountLabel->show();
+        postSharesCountLabel->show();
     }
     else
     {
-        postResharesCountLabel->clear();
-        postResharesCountLabel->hide();
+        postSharesCountLabel->clear();
+        postSharesCountLabel->hide();
     }
 }
 
@@ -1278,27 +1350,38 @@ void Post::setFuzzyTimestamps()
 
     if (!postUpdatedAtString.isEmpty())
     {
-        fuzzyTimestamps.append("\n"
+        fuzzyTimestamps.append("<br>"
                                + tr("Edited: %1")
                                  .arg(Timestamp::fuzzyTime(postUpdatedAtString)));
     }
 
-    this->postCreatedAtLabel->setText(fuzzyTimestamps);
+    this->postCreatedAtLabel->setBaseText(fuzzyTimestamps);
 
-    // Update "share time" on share info tooltip too!
-    if (!sharedByTooltipString.isEmpty())
+    // Update "share time" on share info too!
+    if (!postShareInfoString.isEmpty())
     {
-        QString shareTooltip = sharedByTooltipString;
-        shareTooltip.append(QString("<br>(%1)")
-                            .arg(Timestamp::fuzzyTime(shareTime)));
-        shareTooltip.append(sharedByGeneratorString);
-        this->postIsSharedLabel->setToolTip(shareTooltip);
+        QString shareLabelString;
+        shareLabelString = this->postShareInfoString;
+        shareLabelString.append(Timestamp::fuzzyTime(postShareTime));
+        shareLabelString.append(this->postSharedToCCString);
+        shareLabelString.append(QString::fromUtf8(" &nbsp; &nbsp; "
+                                                  "\342\231\272")); // Recycle symbol, again
+        this->postIsSharedLabel->setText(shareLabelString);
     }
 
     commenter->updateFuzzyTimestamps();
 }
 
 
+void Post::syncAvatarFollowState()
+{
+    this->postAuthorAvatarButton->syncFollowState();
+
+    // Ask CommenterBlock to update its avatars too
+    this->commenter->updateAvatarFollowStates();
+}
+
+
 
 ////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////// SLOTS ///////////////////////////////////
@@ -1472,6 +1555,7 @@ void Post::unsharePost()
 void Post::editPost()
 {
     this->globalObj->editPost(this->postId,
+                              this->postType,
                               this->postTitle,
                               this->postOriginalText);
     if (standalone)
