@@ -94,6 +94,7 @@ public:
     int getHighlightType();
 
     void setFuzzyTimestamps();
+    void syncAvatarFollowState();
 
     enum PostHightlightType
     {
@@ -158,6 +159,7 @@ private:
     QHBoxLayout *mainLayout;
     QVBoxLayout *leftColumnLayout;
     QVBoxLayout *rightColumnLayout;
+    QVBoxLayout *outerLayout;
 
     QFrame *leftColumnFrame;
     QFrame *rightColumnFrame;
@@ -169,9 +171,9 @@ private:
     QString postAuthorName;
 
     QString postSharedById;
-    QString sharedByTooltipString;
-    QString sharedByGeneratorString;
-    QString shareTime;
+    QString postShareInfoString;
+    QString postSharedToCCString;
+    QString postShareTime;
 
     bool postIsOwn;
     bool postIsUnread;
@@ -186,6 +188,7 @@ private:
 
     QLabel *postAuthorNameLabel;
     HClabel *postCreatedAtLabel;
+    QLabel *postGeneratorLabel;
     HClabel *postLocationLabel;
     QLabel *postToLabel;
     QLabel *postCCLabel;
@@ -193,7 +196,7 @@ private:
 
     HClabel *postLikesCountLabel;
     QLabel *postCommentsCountLabel;
-    HClabel *postResharesCountLabel;
+    HClabel *postSharesCountLabel;
 
     QPushButton *openParentPostButton;
 
