@@ -25,7 +25,8 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
                              QWidget *parent) : QWidget(parent)
 {
     this->setWindowTitle(tr("Profile Editor") + " - Dianara");
-    this->setWindowIcon(QIcon::fromTheme("user-properties"));
+    this->setWindowIcon(QIcon::fromTheme("user-properties",
+                                         QIcon(":/images/no-avatar.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
     this->setMinimumSize(500, 400);
@@ -168,6 +169,10 @@ void ProfileEditor::setProfileData(QString avatarUrl, QString fullName,
                                                                     Qt::KeepAspectRatio,
                                                                     Qt::SmoothTransformation));
     }
+    else
+    {
+        // FIXME: Should fetch the avatar
+    }
 
     this->fullNameLineEdit->setText(fullName);
     this->hometownLineEdit->setText(hometown);
