@@ -28,7 +28,8 @@ ProxyDialog::ProxyDialog(int proxyType,
                          QWidget *parent) : QWidget(parent)
 {
     this->setWindowTitle(tr("Proxy Configuration") + " - Dianara");
-    this->setWindowIcon(QIcon::fromTheme("preferences-system-network"));
+    this->setWindowIcon(QIcon::fromTheme("preferences-system-network",
+                                         QIcon(":/images/button-configure.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::WindowModal);
     this->setMinimumSize(380, 320);
