@@ -38,8 +38,8 @@ Publisher::Publisher(PumpController *pumpController,
     this->globalObj = globalObject;
     connect(globalObj, SIGNAL(messagingModeRequested(QString,QString)),
             this, SLOT(startMessageForContact(QString,QString)));
-    connect(globalObj, SIGNAL(postEditRequested(QString,QString,QString)),
-            this, SLOT(setEditingMode(QString,QString,QString)));
+    connect(globalObj, SIGNAL(postEditRequested(QString,QString,QString,QString)),
+            this, SLOT(setEditingMode(QString,QString,QString,QString)));
 
 
     this->postType = "note";
@@ -47,6 +47,8 @@ Publisher::Publisher(PumpController *pumpController,
     this->editingMode = false; // False unless set from setEditingMode
                                // after clicking "Edit" in a post
 
+    this->defaultPublicPosting = false; // initialize
+
     this->setFocusPolicy(Qt::StrongFocus); // To keep the publisher from getting focus by accident
 
 
@@ -137,26 +139,29 @@ Publisher::Publisher(PumpController *pumpController,
     connect(toFollowersAction, SIGNAL(toggled(bool)),
             this, SLOT(setToFollowers(bool)));
 
-    toSelectorListsMenu = new QMenu(tr("Lists"));
+    toSelectorListsMenu = new QMenu(tr("Lists"), this);
     toSelectorListsMenu->setDisabled(true); // Disabled until lists are received, if any
     connect(toSelectorListsMenu, SIGNAL(triggered(QAction*)),
             this, SLOT(updateToListsFields(QAction*)));
 
-    toSelectorMenu = new QMenu("to-menu");
+    toSelectorMenu = new QMenu("to-menu", this);
     toSelectorMenu->addAction(toPublicAction);
     toSelectorMenu->addAction(toFollowersAction);
     toSelectorMenu->addMenu(toSelectorListsMenu);
     toSelectorMenu->addSeparator();
-    toSelectorMenu->addAction(tr("People..."), audienceSelectorTo, SLOT(show()));
+    toSelectorMenu->addAction(tr("People..."),
+                              audienceSelectorTo, SLOT(show()));
 
-    toSelectorButton = new QPushButton(QIcon::fromTheme("system-users"),
+    toSelectorButton = new QPushButton(QIcon::fromTheme("system-users",
+                                                        QIcon(":/images/no-avatar.png")),
                                      tr("To..."));
-    toSelectorButton->setToolTip(tr("Select who will see this post"));
+    toSelectorButton->setToolTip("<b></b>"
+                                 + tr("Select who will see this post"));
     toSelectorButton->setMenu(toSelectorMenu);
 
 
 
-    // CC... menu
+    // Cc... menu
     ccPublicAction = new QAction(tr("Public"), this);
     ccPublicAction->setCheckable(true);
     connect(ccPublicAction, SIGNAL(toggled(bool)),
@@ -167,28 +172,31 @@ Publisher::Publisher(PumpController *pumpController,
     connect(ccFollowersAction, SIGNAL(toggled(bool)),
             this, SLOT(setCCFollowers(bool)));
 
-    ccSelectorListsMenu = new QMenu(tr("Lists"));
+    ccSelectorListsMenu = new QMenu(tr("Lists"), this);
     ccSelectorListsMenu->setDisabled(true); // Disabled until lists are received, if any
     connect(ccSelectorListsMenu, SIGNAL(triggered(QAction*)),
             this, SLOT(updateCcListsFields(QAction*)));
 
-    ccSelectorMenu = new QMenu("cc-menu");
+    ccSelectorMenu = new QMenu("cc-menu", this);
     ccSelectorMenu->addAction(ccPublicAction);
     ccSelectorMenu->addAction(ccFollowersAction);
     ccSelectorMenu->addMenu(ccSelectorListsMenu);
     ccSelectorMenu->addSeparator();
-    ccSelectorMenu->addAction(tr("People..."), audienceSelectorCC, SLOT(show()));
+    ccSelectorMenu->addAction(tr("People..."),
+                              audienceSelectorCC, SLOT(show()));
 
-    ccSelectorButton = new QPushButton(QIcon::fromTheme("system-users"),
-                                     tr("CC..."));
-    ccSelectorButton->setToolTip(tr("Select who will get a copy of this post"));
+    ccSelectorButton = new QPushButton(QIcon::fromTheme("system-users",
+                                                        QIcon(":/images/no-avatar.png")),
+                                     tr("Cc..."));
+    ccSelectorButton->setToolTip("<b></b>"
+                                 + tr("Select who will get a copy of this post"));
     ccSelectorButton->setMenu(ccSelectorMenu);
 
 
-    QFont audienceLabelsFont; // "To" column will be normal, "CC" will be italic
-    audienceLabelsFont.setPointSize(audienceLabelsFont.pointSize()-1);
+    QFont audienceLabelsFont; // "To" column will be normal, "Cc" will be italic
+    audienceLabelsFont.setPointSize(audienceLabelsFont.pointSize() - 1);
 
-    // These will hold the names of the *people* selected for the To or CC fields, if any
+    // These will hold the names of the *people* selected for the To or Cc fields, if any
     toAudienceLabel = new QLabel();
     toAudienceLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     toAudienceLabel->setFont(audienceLabelsFont);  // Normal
@@ -218,22 +226,26 @@ Publisher::Publisher(PumpController *pumpController,
 
 
     // Menu to set the picture/audio/video modes, under an "Add..." button
-    addMediaImageAction = new QAction(QIcon::fromTheme("camera-photo"),
+    addMediaImageAction = new QAction(QIcon::fromTheme("camera-photo",
+                                                       QIcon(":/images/attached-image.png")),
                                       tr("Picture"), this);
     connect(addMediaImageAction, SIGNAL(triggered()),
             this, SLOT(setPictureMode()));
 
-    addMediaAudioAction = new QAction(QIcon::fromTheme("audio-input-microphone"),
+    addMediaAudioAction = new QAction(QIcon::fromTheme("audio-input-microphone",
+                                                       QIcon(":/images/attached-audio.png")),
                                       tr("Audio"), this);
     connect(addMediaAudioAction, SIGNAL(triggered()),
             this, SLOT(setAudioMode()));
 
-    addMediaVideoAction = new QAction(QIcon::fromTheme("camera-web"),
+    addMediaVideoAction = new QAction(QIcon::fromTheme("camera-web",
+                                                       QIcon(":/images/attached-video.png")),
                                       tr("Video"), this);
     connect(addMediaVideoAction, SIGNAL(triggered()),
             this, SLOT(setVideoMode()));
 
-    addMediaFileAction = new QAction(QIcon::fromTheme("application-octet-stream"),
+    addMediaFileAction = new QAction(QIcon::fromTheme("application-octet-stream",
+                                                      QIcon(":/images/attached-file.png")),
                                      tr("Other", "as in other kinds of files"),
                                      this);
     connect(addMediaFileAction, SIGNAL(triggered()),
@@ -241,16 +253,18 @@ Publisher::Publisher(PumpController *pumpController,
 
 
     // The menu itself
-    addMediaMenu = new QMenu();
+    addMediaMenu = new QMenu("add-media-menu", this);
     addMediaMenu->addAction(addMediaImageAction);
     addMediaMenu->addAction(addMediaAudioAction);
     addMediaMenu->addAction(addMediaVideoAction);
     addMediaMenu->addAction(addMediaFileAction);
 
     // The "add..." button holding the menu
-    addMediaButton = new QPushButton(QIcon::fromTheme("mail-attachment"),
+    addMediaButton = new QPushButton(QIcon::fromTheme("mail-attachment",
+                                                      QIcon(":/images/list-add.png")),
                                     tr("Ad&d..."));
-    addMediaButton->setToolTip(tr("Upload media, like pictures or videos"));
+    addMediaButton->setToolTip("<b></b>"
+                               + tr("Upload media, like pictures or videos"));
     addMediaButton->setMenu(addMediaMenu);
 
 
@@ -268,15 +282,17 @@ Publisher::Publisher(PumpController *pumpController,
     // To send the post
     postButton = new QPushButton(QIcon::fromTheme("mail-send",
                                                   QIcon(":/images/button-post.png")),
-                                  tr("Post"));
-    postButton->setToolTip(tr("Hit Control+Enter to post with the keyboard"));
+                                  tr("Post", "verb"));
+    postButton->setToolTip("<b></b>"
+                           + tr("Hit Control+Enter to post with the keyboard"));
     connect(postButton, SIGNAL(clicked()),
             this, SLOT(sendPost()));
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
                                    tr("Cancel"));
-    cancelButton->setToolTip(tr("Cancel the post"));
+    cancelButton->setToolTip("<b></b>"
+                             + tr("Cancel the post"));
     connect(cancelButton, SIGNAL(clicked()),
             composerBox, SLOT(cancelPost()));
 
@@ -318,6 +334,14 @@ Publisher::Publisher(PumpController *pumpController,
     // The "Cancel post" button
     mainLayout->addWidget(cancelButton,        8, 7, 1, 1);
 
+#ifdef GROUPSUPPORT
+    groupIdLabel = new QLabel("TO GROUP (ID):");
+    mainLayout->addWidget(groupIdLabel,        9, 0, 1, 1);
+    groupIdLineEdit = new QLineEdit();
+    mainLayout->addWidget(groupIdLineEdit,     9, 1, 1, 7);
+#endif
+
+
     this->setLayout(mainLayout);
 
 
@@ -405,6 +429,7 @@ void Publisher::updatePublicFollowersLabels()
  *
  * "collection" : "http://activityschema.org/collection/public"
  * "collection" : "https://pump.example/api/user/followers"
+ * "group"      : "https://pump.example/api/user/group/someGroupId123"
  * "person"     : "acct:somecontact@pumpserver.example"
  *
  */
@@ -412,57 +437,82 @@ QMap<QString,QString> Publisher::getAudienceMap()
 {
     QMap<QString,QString> audienceMap;
 
+    onlyToFollowers = true; // Will be set to false if something else is enabled
+    // Used to warn the user when posting only to followers having none
 
     // To: Public is checked
     if (toPublicAction->isChecked())
     {
-        audienceMap.insertMulti("to|collection", "http://activityschema.org/collection/public");
+        onlyToFollowers = false;
+        audienceMap.insertMulti("to|collection",
+                                "http://activityschema.org/collection/public");
     }
 
     // To: List of individual people
     foreach (QString address, this->toAddressStringList)
     {
-        audienceMap.insertMulti("to|person", "acct:" + address);
+        onlyToFollowers = false;
+        audienceMap.insertMulti("to|person",
+                                "acct:" + address);
     }
 
     // To: Lists
     foreach (QString address, this->toListsIdStringList)
     {
-        audienceMap.insertMulti("to|collection", address);
+        onlyToFollowers = false;
+        audienceMap.insertMulti("to|collection",
+                                address);
     }
 
 
     // To: Followers is checked
     if (toFollowersAction->isChecked())
     {
-        audienceMap.insertMulti("to|collection", this->pController->currentFollowersUrl());
+        audienceMap.insertMulti("to|collection",
+                                this->pController->currentFollowersUrl());
     }
 
 
-    // CC: Public is checked
+    // Cc: Public is checked
     if (ccPublicAction->isChecked())
     {
-        audienceMap.insertMulti("cc|collection", "http://activityschema.org/collection/public");
+        onlyToFollowers = false;
+        audienceMap.insertMulti("cc|collection",
+                                "http://activityschema.org/collection/public");
     }
 
-    // CC: List of individual people
+    // Cc: List of individual people
     foreach (QString address, this->ccAddressStringList)
     {
-        audienceMap.insertMulti("cc|person", "acct:" + address);
+        onlyToFollowers = false;
+        audienceMap.insertMulti("cc|person",
+                                "acct:" + address);
     }
 
-    // CC: Lists
+    // Cc: Lists
     foreach (QString address, this->ccListsIdStringList)
     {
-        audienceMap.insertMulti("cc|collection", address);
+        onlyToFollowers = false;
+        audienceMap.insertMulti("cc|collection",
+                                address);
     }
 
+#ifdef GROUPSUPPORT
+    // Cc: Groups
+    if (!groupIdLineEdit->text().trimmed().isEmpty())
+    {
+        onlyToFollowers = false;
+        audienceMap.insertMulti("to|group", groupIdLineEdit->text().trimmed());
+    }
+#endif
 
 
-    // Last check: if CC: Followers is checked, or nothing is, add Followers
+    // Last check: if Cc: Followers is checked, or nothing is, add Followers
     if (ccFollowersAction->isChecked() || audienceMap.isEmpty())
     {
-        audienceMap.insertMulti("cc|collection", this->pController->currentFollowersUrl());
+        // FIXME: maybe fail and warn the user instead
+        audienceMap.insertMulti("cc|collection",
+                                this->pController->currentFollowersUrl());
     }
 
 
@@ -578,10 +628,10 @@ void Publisher::setMinimumMode()
     toFollowersAction->setChecked(false);
 
     ccPublicAction->setChecked(false);
-    ccFollowersAction->setChecked(true);  // CC: Followers by default
+    ccFollowersAction->setChecked(true);  // Cc: Followers by default
 
     // Uncheck the lists, very TMP / FIXME
-    // This doesn't clear the To/CC labels sometimes
+    // This doesn't clear the To/Cc labels sometimes
     foreach (QAction *action, toSelectorListsMenu->actions())
     {
         action->setChecked(false);
@@ -624,13 +674,20 @@ void Publisher::setMinimumMode()
         this->editingMode = false;
         this->editingPostId.clear();
 
-        this->postButton->setText(tr("Post")); // Button text back to "Post" as usual
+        this->postButton->setText(tr("Post",
+                                     "verb")); // Button text back to "Post" as usual
         this->toSelectorButton->setEnabled(true);
         this->ccSelectorButton->setEnabled(true);
         this->addMediaButton->setEnabled(true);
     }
 
     this->fullMode = false;
+
+#ifdef GROUPSUPPORT
+    this->groupIdLabel->hide();
+    this->groupIdLineEdit->hide();
+    this->groupIdLineEdit->clear();
+#endif
 }
 
 
@@ -676,6 +733,11 @@ void Publisher::setFullMode()
                                    // instead of clicking on it
 
     this->fullMode = true;
+
+#ifdef GROUPSUPPORT
+    this->groupIdLabel->show();
+    this->groupIdLineEdit->show();
+#endif
 }
 
 
@@ -776,7 +838,7 @@ void Publisher::setFileMode()
  * Set Publiser to edit mode, after user clicks on "Edit" in a post
  *
  */
-void Publisher::setEditingMode(QString postId,
+void Publisher::setEditingMode(QString postId, QString postType,
                                QString postTitle, QString postText)
 {
     // Prevent the "Edit" option from destroying a post currently being composed!
@@ -790,6 +852,7 @@ void Publisher::setEditingMode(QString postId,
 
     this->editingMode = true;
     this->editingPostId = postId;
+    this->postType = postType;
     setFullMode();
 
 
@@ -833,7 +896,7 @@ void Publisher::startMessageForContact(QString name, QString id)
 
     setFullMode();
 
-    // Unselect Public and Followers from To/CC
+    // Unselect Public and Followers from To/Cc
     toPublicAction->setChecked(false);
     toFollowersAction->setChecked(false);
     ccPublicAction->setChecked(false);
@@ -884,14 +947,14 @@ void Publisher::onPublishingFailed()
 /*
  * These are called when selecting Public or Followers in the menus
  *
- * When selecting "CC: Followers", "To: Followers" gets unselected, etc.
+ * When selecting "Cc: Followers", "To: Followers" gets unselected, etc.
  *
  */
 void Publisher::setToPublic(bool activated)
 {
     if (activated)
     {
-        ccPublicAction->setChecked(false);     // Unselect "CC: Public"
+        ccPublicAction->setChecked(false);     // Unselect "Cc: Public"
     }
     updatePublicFollowersLabels();
 }
@@ -900,7 +963,7 @@ void Publisher::setToFollowers(bool activated)
 {
     if (activated)
     {
-        ccFollowersAction->setChecked(false);  // Unselect "CC: Followers"
+        ccFollowersAction->setChecked(false);  // Unselect "Cc: Followers"
     }
     updatePublicFollowersLabels();
 }
@@ -927,7 +990,7 @@ void Publisher::setCCFollowers(bool activated)
 
 
 /*
- * Receive a list of addresses for the To or CC fields
+ * Receive a list of addresses for the To or Cc fields
  *
  */
 void Publisher::updateToCcFields(QString selectorType,
@@ -1048,14 +1111,14 @@ void Publisher::updateCcListsFields(QAction *listAction)
 
     if (listAction->isChecked())
     {
-        qDebug() << "CC list selected" << listName << listId;
+        qDebug() << "Cc list selected" << listName << listId;
 
         ccListsNameStringList.append(listName);
         ccListsIdStringList.append(listId);
     }
     else
     {
-        qDebug() << "CC list unselected" << listName;
+        qDebug() << "Cc list unselected" << listName;
 
         ccListsNameStringList.removeAll(listName);
         ccListsIdStringList.removeAll(listId);
@@ -1063,7 +1126,7 @@ void Publisher::updateCcListsFields(QAction *listAction)
 
     this->updatePublicFollowersLabels();
 
-    qDebug() << "Current CC Lists:" << ccListsNameStringList << ccListsIdStringList;
+    qDebug() << "Current Cc Lists:" << ccListsNameStringList << ccListsIdStringList;
 }
 
 
@@ -1095,7 +1158,8 @@ void Publisher::showHighlightedUrl(QString url)
  */
 void Publisher::sendPost()
 {
-    qDebug() << "Publisher character count:" << composerBox->textCursor().document()->characterCount();
+    qDebug() << "Publisher character count:" << composerBox->textCursor()
+                                                .document()->characterCount();
 
     bool textIsEmpty;
     if (composerBox->textCursor().document()->characterCount() > 1) // kinda tmp
@@ -1110,16 +1174,56 @@ void Publisher::sendPost()
 
     // If there's some text in the post, or attached media, send it
     if ( (postType == "note" && !textIsEmpty)
-      || (postType != "note" && !mediaFilename.isEmpty()))
+      || (postType != "note" && !mediaFilename.isEmpty())
+      || editingMode ) // Or editing, then the other stuff doesn't matter
     {
         QString postTitle = this->titleLineEdit->text().trimmed();
         postTitle.replace("\n", " "); // Post title could have newlines if copy-pasted
+        if (postTitle.length() > 120) // Limit title length to something sane
+        {
+            postTitle = postTitle.left(115) + " [...]";
+        }
 
         QString cleanHtmlString = MiscHelpers::cleanupHtml(composerBox->toHtml());
 
 
         QMap<QString,QString> audienceMap = this->getAudienceMap();
 
+        // Warn user if posting only to Followers, but having none
+        if (this->onlyToFollowers // Set in getAudienceMap()
+            && this->pController->currentFollowersCount() == 0
+            && !editingMode)
+        {
+            qDebug() << "WARNING: You have no followers yet; Post to public?";
+
+            int action = QMessageBox::warning(this,
+                                 tr("Warning: You have no followers yet"),
+                                 tr("You're trying to post to your followers "
+                                    "only, but you don't have any followers "
+                                    "yet.")
+                                 + " "
+                                 + tr("If you post like this, no one will be "
+                                      "able to see your message.")
+                                 + "\n\n"
+                                 + tr("Do you want to make the post public "
+                                      "instead of followers-only?")
+                                 + "\n",
+                                 tr("&Yes, make it public"),
+                                 tr("&No, post to my followers only"),
+                                 tr("&Cancel, go back to the post"),
+                                 2, 2); // Cancel is default, and also activated with ESC
+            if (action == 0)
+            {
+                this->toPublicAction->setChecked(true);  // Check To:Public
+                audienceMap = this->getAudienceMap();    // Process again
+                qDebug() << "Checked To:Public";
+            }
+            else if (action == 2)
+            {
+                qDebug() << "Posting aborted; back to post composer";
+                return;
+            }
+        }
 
         // Don't erase just yet!! Just disable until we get "200 OK" from the server.
         this->toggleWidgetsWhileSending(false);
@@ -1155,6 +1259,7 @@ void Publisher::sendPost()
         {
             this->statusInfoLabel->setText(tr("Updating..."));
             this->pController->updatePost(this->editingPostId,
+                                          this->postType,
                                           cleanHtmlString,
                                           postTitle);
         }
