@@ -75,9 +75,8 @@ public slots:
     void setVideoMode();
     void setFileMode();
 
-    void setEditingMode(QString postId,
-                        QString postTitle,
-                        QString postText);
+    void setEditingMode(QString postId, QString postType,
+                        QString postTitle, QString postText);
 
 
     void startMessageForContact(QString name,
@@ -150,8 +149,13 @@ private:
     QStringList ccListsNameStringList;
     QStringList ccListsIdStringList;
 
-    bool defaultPublicPosting;
+#ifdef GROUPSUPPORT
+    QLabel *groupIdLabel;
+    QLineEdit *groupIdLineEdit;
+#endif
 
+    bool defaultPublicPosting;
+    bool onlyToFollowers;
 
     QPushButton *addMediaButton;
     QMenu *addMediaMenu;
