@@ -55,11 +55,74 @@
 #include "asperson.h"
 
 
+
 class PumpController : public QObject
 {
     Q_OBJECT
 
 public:
+    enum requestTypes
+    {
+        NoRequest,
+
+        ClientRegistrationRequest,
+        TokenRequest,
+
+        UserProfileRequest,
+        UpdateProfileRequest,
+
+        FollowingListRequest,
+        FollowersListRequest,
+        ListsListRequest,
+        CreatePersonListRequest,
+        DeletePersonListRequest,
+        PersonListRequest,
+        AddMemberToListRequest,
+        RemoveMemberFromListRequest,
+
+        CreateGroupRequest,
+        DeleteGroupRequest,
+        JoinGroupRequest,
+        LeaveGroupRequest,
+
+        MainTimelineRequest,
+        DirectTimelineRequest,
+        ActivityTimelineRequest,
+        FavoritesTimelineRequest,
+
+        PostLikesRequest,
+        PostCommentsRequest,
+        PostSharesRequest,
+
+        MinorFeedMainRequest,
+        MinorFeedDirectRequest,
+        MinorFeedActivityRequest,
+
+        PublishPostRequest,
+        LikePostRequest,
+        CommentPostRequest,
+        SharePostRequest,
+        UnsharePostRequest,
+        DeletePostRequest,
+
+        UpdatePostRequest,
+        UpdateCommentRequest,
+
+        FollowContactRequest,
+        UnfollowContactRequest,
+
+
+        AvatarRequest,
+        ImageRequest,
+        MediaRequest,
+
+        UploadFileRequest,
+        UploadMediaForPostRequest,
+        UploadAvatarRequest,
+        PublishAvatarRequest
+    };
+
+
     explicit PumpController(QObject *parent = 0);
     ~PumpController();
 
@@ -123,19 +186,19 @@ public:
     void getPostComments(QString postCommentsUrl);
     void getPostShares(QString postSharesUrl);
 
-    void getMinorFeed(int offset = 0);
+    void getMinorFeed(requestTypes feedType, int offset = 0);
     void getMinorFeedProper(QString url = "");
 
     QNetworkRequest prepareRequest(QString url,
                                    QOAuth::HttpMethod method,
-                                   int requestType,
+                                   requestTypes requestType,
                                    QOAuth::ParamMap paramMap = QOAuth::ParamMap(),
                                    QString contentTypeString="application/json");
 
     QByteArray prepareJSON(QVariantMap jsonVariantMap);
 
     QNetworkReply *uploadFile(QString filename, QString contentType,
-                              int uploadType = UploadFileRequest);
+                              requestTypes uploadType = UploadFileRequest);
 
     QList<QVariantList> processAudience(QMap<QString,QString> audienceMap);
 
@@ -143,66 +206,6 @@ public:
 
     void showStatusMessageAndLogIt(QString message);
 
-    enum requestTypes
-    {
-        NoRequest,
-
-        ClientRegistrationRequest,
-        TokenRequest,
-
-        UserProfileRequest,
-        UpdateProfileRequest,
-
-        FollowingListRequest,
-        FollowersListRequest,
-        ListsListRequest,
-        CreatePersonListRequest,
-        DeletePersonListRequest,
-        PersonListRequest,
-        AddMemberToListRequest,
-        RemoveMemberFromListRequest,
-
-        CreateGroupRequest,
-        DeleteGroupRequest,
-        JoinGroupRequest,
-        LeaveGroupRequest,
-
-        MainTimelineRequest,
-        DirectTimelineRequest,
-        ActivityTimelineRequest,
-        FavoritesTimelineRequest,
-
-        PostLikesRequest,
-        PostCommentsRequest,
-        PostSharesRequest,
-
-        MinorFeedRequest,
-
-        PublishPostRequest,
-        LikePostRequest,
-        CommentPostRequest,
-        SharePostRequest,
-        UnsharePostRequest,
-        DeletePostRequest,
-
-        UpdatePostRequest,
-        UpdateCommentRequest,
-
-        FollowContactRequest,
-        UnfollowContactRequest,
-
-
-        AvatarRequest,
-        ImageRequest,
-        MediaRequest,
-
-        UploadFileRequest,
-        UploadMediaForPostRequest,
-        UploadAvatarRequest,
-        PublishAvatarRequest
-    };
-
-
 
 
 signals:
@@ -218,6 +221,7 @@ signals:
                              int totalReceivedCount);
     void contactFollowed(ASPerson *contact);
     void contactUnfollowed(ASPerson *contact);
+    void followingListChanged();
 
     void listsListReceived(QVariantList listsList);
     void personListReceived(QVariantList personList, QString listUrl);
@@ -241,8 +245,12 @@ signals:
     void likesReceived(QVariantList likesList, QString originatingPostURL);
     void commentsReceived(QVariantList commentsList, QString originatingPostURL);
 
-    void minorFeedReceived(QVariantList activitiesList,
-                           QString previousLink, QString nextLink);
+    void minorFeedMainReceived(QVariantList activitiesList,
+                               QString previousLink, QString nextLink);
+    void minorFeedDirectReceived(QVariantList activitiesList,
+                                 QString previousLink, QString nextLink);
+    void minorFeedActivityReceived(QVariantList activitiesList,
+                                   QString previousLink, QString nextLink);
 
     void avatarPictureReceived(QByteArray pictureData, QUrl pictureURL);
     void imageReceived(QByteArray pictureData, QUrl pictureURL);
@@ -284,12 +292,11 @@ public slots:
                              QString mediaFilename, QString mediaType,
                              QString mimeContentType);
     void postMediaStepTwo(QString id);
-    void postMediaStepThree(QString id);
 
     void postAvatarStepTwo(QString id);
 
 
-    void updatePost(QString id, QString content, QString title);
+    void updatePost(QString id, QString type, QString content, QString title);
 
     void likePost(QString postID, QString postType, bool like);
 
@@ -323,6 +330,8 @@ private:
     QString userId;  // Full webfinger address, user@host.tld
     QString userName;
     QString serverURL;
+    QString apiBaseUrl;
+    QString apiFeedUrl;
 
     bool proxyUsesAuth;
 
@@ -344,7 +353,9 @@ private:
     bool haveDirectTL;
     bool haveActivityTL;
     bool haveFavoritesTL;
-    bool haveMinorFeed;
+    bool haveMainMF;
+    bool haveDirectMF;
+    bool haveActivityMF;
 
 
     int postsPerPageMain;
