@@ -51,7 +51,9 @@ TimeLine::TimeLine(int timelineType,
     QVariantMap demoObjectData;
     demoObjectData.insert("objectType",     "note");
     demoObjectData.insert("id",             "demo-post-id");
-    demoObjectData.insert("published",      "2013-05-01T00:00:00Z");
+
+    // Show date/time when Dianara v1.2.5 was released
+    demoObjectData.insert("published",      "2014-12-16T18:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -98,8 +100,8 @@ TimeLine::TimeLine(int timelineType,
 
                               + "<a href=\"http://jancoding.wordpress.com/dianara\">"
                               + tr("Dianara's blog") + "</a><br><br>"
-                                "<a href=\"https://github.com/e14n/pump.io/wiki/FAQ\">"
-                              + tr("Frequently asked questions about Pump.io")
+                                "<a href=\"https://github.com/e14n/pump.io/wiki/User-Guide\">"
+                              + tr("Pump.io User Guide")
                               + "</a>"
                               + "<br><br>");
 
@@ -111,7 +113,7 @@ TimeLine::TimeLine(int timelineType,
         demoObjectData.insert("displayName",  tr("Direct Messages Timeline"));
         demoObjectData.insert("content",      tr("Here, you'll see posts "
                                                  "specifically directed to you.")
-                                              + "<br><br>");
+                                              + "<br><br><br>");
         this->previousNewestPostId = settings.value("previousNewestPostIdDirect").toString();
         break;
 
@@ -119,7 +121,7 @@ TimeLine::TimeLine(int timelineType,
     case TimelineTypeActivity:
         demoObjectData.insert("displayName", tr("Activity Timeline"));
         demoObjectData.insert("content",     tr("You'll see your own posts here.")
-                                             + "<br><br>");
+                                             + "<br><br><br>");
         this->previousNewestPostId = settings.value("previousNewestPostIdActivity").toString();
         break;
 
@@ -127,7 +129,7 @@ TimeLine::TimeLine(int timelineType,
     case TimelineTypeFavorites:
         demoObjectData.insert("displayName", tr("Favorites Timeline"));
         demoObjectData.insert("content",     tr("Posts and comments you've liked.")
-                                             + "<br><br>");
+                                             + "<br><br><br>");
         this->previousNewestPostId = settings.value("previousNewestPostIdFavorites").toString();
         break;
 
@@ -282,6 +284,10 @@ TimeLine::TimeLine(int timelineType,
 
     this->updateCurrentPageNumber();
 
+    // Sync avatar's follow state for every post when there are changes in the Following list
+    connect(pController, SIGNAL(followingListChanged()),
+            this, SLOT(updateAvatarFollowStates()));
+
     qDebug() << "TimeLine created";
 }
 
@@ -298,25 +304,29 @@ TimeLine::~TimeLine()
     switch (timelineType)
     {
     case TimelineTypeMain:
-        settings.setValue("previousNewestPostIdMain", this->previousNewestPostId);
+        settings.setValue("previousNewestPostIdMain",
+                          this->previousNewestPostId);
         break;
 
     case TimelineTypeDirect:
-        settings.setValue("previousNewestPostIdDirect", this->previousNewestPostId);
+        settings.setValue("previousNewestPostIdDirect",
+                          this->previousNewestPostId);
         break;
 
     case TimelineTypeActivity:
-        settings.setValue("previousNewestPostIdActivity", this->previousNewestPostId);
+        settings.setValue("previousNewestPostIdActivity",
+                          this->previousNewestPostId);
         break;
 
     case TimelineTypeFavorites:
-        settings.setValue("previousNewestPostIdFavorites", this->previousNewestPostId);
+        settings.setValue("previousNewestPostIdFavorites",
+                          this->previousNewestPostId);
         break;
     }
     settings.endGroup();
 
 
-    qDebug() << "TimeLine destroyed";
+    qDebug() << "TimeLine destroyed; Type:" << this->timelineType;
 }
 
 
@@ -835,3 +845,11 @@ void TimeLine::decreaseUnreadPostsCount(bool wasHighlighted)
                                  this->newHighlightedPostsCount,
                                  this->totalItemsCount);
 }
+
+void TimeLine::updateAvatarFollowStates()
+{
+    foreach (Post *post, postsInTimeline)
+    {
+        post->syncAvatarFollowState();
+    }
+}
