@@ -102,6 +102,7 @@ public slots:
 
     void setLikesInPost(QVariantList likesList, QString originatingPostURL);
     void setCommentsInPost(QVariantList commentsList, QString originatingPostURL);
+    //void setSharesInPost(...)
 
     void goToFirstPage();
     void goToPreviousPage();
@@ -119,6 +120,8 @@ public slots:
 
     void decreaseUnreadPostsCount(bool wasHighlighted);
 
+    void updateAvatarFollowStates();
+
 protected:
 
 
